//-----------------------------------------------------------------------
// <copyright file="CommonConstants.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that is used to manage CommonConstants.</summary>
//-----------------------------------------------------------------------
namespace BusinessLogicLayer.Utilities
{
    /// <summary>
    /// Class that holds constants.
    /// </summary>
    public static class CommonConstants
    {
        #region Public Enums

        /// <summary>
        /// Holds the mandatory actions.
        /// </summary>
        public enum TimesheetActions
        {
            /// <summary>Save Action.</summary>
            Save = 1,

            /// <summary>Submit Action.</summary>
            Submit = 2,

            /// <summary>Approve Action.</summary>
            Approve = 3,

            /// <summary>Decline Action.</summary>
            Decline = 4
        }

        /// <summary>
        /// Holds the mandatory Statuses.
        /// </summary>
        public enum TimesheetStatuses
        {
            /// <summary>Saved State.</summary>
            Saved = 1,

            /// <summary>Submitted State.</summary>
            Submitted = 2,

            /// <summary>Approve State.</summary>
            Approved = 3,

            /// <summary>Declined State.</summary>
            Declined = 4
        }

        /// <summary>
        /// Holds the mandatory Role id.
        /// </summary>
        public enum Roles : short
        {
            /// <summary>Standard Role.</summary>
            Standard = 1,

            /// <summary>Administrator Role.</summary>
            Administrator = 2,

            /// <summary>Manager Role.</summary>
            Manager = 3
        }

        #endregion Public Enums

        #region Public Static Properties

        /// <summary>Gets Reg Ex for email.</summary>
        public static string EmailRegEx
        {
            get
            {
                return @"^(([^<>()[\]\\.,;:\s@\""]+"
                           + @"(\.[^<>()[\]\\.,;:\s@\""]+)*)|(\"".+\""))@"
                           + @"((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}"
                           + @"\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+"
                           + @"[a-zA-Z]{2,}))$";
            }
        }

        /// <summary>Gets the Min Password Length.</summary>
        public static int MinPasswordLength
        {
            get { return 7; }
        }

        #endregion Public Static Properties

        #region Public Static Classes

        /// <summary>
        /// Holds the mandatory Role Names.
        /// </summary>
        public static class RoleNames
        {
            /// <summary>Administrator Role.</summary>
            public const string Administrator = "administrator";

            /// <summary>Standard Role.</summary>
            public const string Standard = "standard";

            /// <summary>Manager Role.</summary>
            public const string Manager = "manager";
        }

        #endregion Public Static Classes
    }
}
