//-----------------------------------------------------------------------
// <copyright file="Validators.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that is used verify input.</summary>
//-----------------------------------------------------------------------
namespace BusinessLogicLayer.Utilities
{
    using System.Text.RegularExpressions;

    /// <summary>
    /// Class used to verify user input.
    /// </summary>
    public static class Validators
    {
        /// <summary>
        /// Checks to see if name is valid.
        /// </summary>
        /// <param name="name">Name to validate.</param>
        /// <returns>True if valid, false if not.</returns>
        public static bool IsValidName(string name)
        {
            return !string.IsNullOrEmpty(name);
        }

        /// <summary>
        /// Checks to see if email is valid.
        /// </summary>
        /// <param name="email">Email to validate.</param>
        /// <returns>True if valid, false if not.</returns>
        public static bool IsValidEmail(string email)
        {
            Regex regex = new Regex(CommonConstants.EmailRegEx);
            return regex.IsMatch(email);
        }

        /// <summary>
        /// Checks to see if password is valid.
        /// </summary>
        /// <param name="password">Password to validate.</param>
        /// <returns>True if valid, false if not.</returns>
        public static bool IsValidPassword(string password)
        {
            if (password.Contains(" ") || password.Length < CommonConstants.MinPasswordLength)
            {
                return false;
            }

            return true;
        }
    }
}
