﻿//-----------------------------------------------------------------------
// <copyright file="CryptographerTest.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that allows Cryptographer to be tested.</summary>
//-----------------------------------------------------------------------
namespace BusinessLogicLayerTest
{
    using System;
    using System.Collections.Generic;
    using System.Text;
    using System.Threading;
    using System.Web;
    using BusinessLogicLayer.Utilities;
    using Microsoft.VisualStudio.TestTools.UnitTesting; 

    /// <summary>
    /// This is a test class for BusinessLogicLayer.Utilities.Cryptographer and is intended
    /// to contain all BusinessLogicLayer.Utilities.Cryptographer Unit Tests
    /// </summary>
    [TestClass()]
    public class CryptographerTest
    {
        #region Private Members

        /// <summary>Key used in encryption and decryption.</summary>
        private string key = "ZeroCool";

        /// <summary>vector used in encryption and decryption.</summary>
        private string vector = "ZeroCool";

        /// <summary>RSA Private Key</summary>
        private string rsaPrivateKey = "<RSAKeyValue><Modulus>xY7DvF4RIHF0AUlnWwdsvkzviVbQNjUIACuOeHlsKRhfeddA/0mZouEhUNwBfByQE0ddBGsy6r0mTYnhtaAFzdtTtpdVc+3x/o7lnzdubQM2ecVO2jG6C+YgU1ny32SPwJwMiXLAa1uTIt9zP9kqDjCAsG9OglArdqc1hNLtnMk=</Modulus><Exponent>AQAB</Exponent><P>7pQEPB5+//5LolsB0txb8Ed51+9dyGtL2oSieiJPZfvV11tWfHVHQQhwV4a2DwLN7omKZZaVWAmRUE5umOl2XQ==</P><Q>0/vo+YD0ldEXkGBeFA1LglnpAxDFqEvgpqpFnKxqD3Y3i11o/lTNQSuhwU3Uj95RYg3v5845KEX9Ky726lBBXQ==</Q><DP>PQQcBSgjgOMPgulVkREMbmpJTiGI0a4nSy6qwyOtPL7olNhmSRRRcd9vo+LvAu3Lrxr8Czk03rwrrucwP+lNfQ==</DP><DQ>QxnleD0aruW96MSoYv6GXV+qg37mokxKc1dIq7xj4jsQf/v0hTVAt5VhIXhKhbPg3QH+Y8kCjL4C0o2OOUNoPQ==</DQ><InverseQ>YPGOFQolADE3ku0C4No6iTJLxpvtoLtaqk5tN00J8xgQehAoijoukobfv2E61EZpNOKzQ8qQSHJDquEudamzQA==</InverseQ><D>YZlDN/cc7PM/xTb3WbBUV7t4h1gdKvqOBk9+ZiROfArveCkQkk5RGXexVtop3Z/aybtyx7ESCYgCuUHKAUmaM5d0ejPMj2T7S9d/g6IKxfPEw/pjgsPd4HFlF4GnBRqZiKZkr53R1Fw1K/uEArJVv7Vc6IJei5e/43Zd0xI0JJE=</D></RSAKeyValue>";

        /// <summary>RSA Public Key</summary>
        private string rsaPublicKey = "<RSAKeyValue><Modulus>xY7DvF4RIHF0AUlnWwdsvkzviVbQNjUIACuOeHlsKRhfeddA/0mZouEhUNwBfByQE0ddBGsy6r0mTYnhtaAFzdtTtpdVc+3x/o7lnzdubQM2ecVO2jG6C+YgU1ny32SPwJwMiXLAa1uTIt9zP9kqDjCAsG9OglArdqc1hNLtnMk=</Modulus><Exponent>AQAB</Exponent></RSAKeyValue>";

        #endregion Private Members

        #region DES Tests

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        public void DESEncryptTest()
        {
            string data = "password";
            string expected = "HCv368BmiLGqNYfQNF74mA==";
            string actual = BusinessLogicLayer.Utilities.Cryptographer.Encrypt(data, Cryptographer.EncryptionType.DES, this.key, this.vector);
            Assert.AreEqual(expected, actual, "BusinessLogicLayer.Utilities.Cryptographer.Encrypt did not return the expected value.");
        }

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        [ExpectedException(typeof(ArgumentNullException))]
        public void DESEncryptTest1()
        {
            BusinessLogicLayer.Utilities.Cryptographer.Encrypt("password", Cryptographer.EncryptionType.DES, null, this.vector);
        }

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        [ExpectedException(typeof(ArgumentNullException))]
        public void DESEncryptTest2()
        {
            BusinessLogicLayer.Utilities.Cryptographer.Encrypt("password", Cryptographer.EncryptionType.DES, this.key, null);
        }

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        [ExpectedException(typeof(ArgumentNullException))]
        public void DESEncryptTest3()
        {
            BusinessLogicLayer.Utilities.Cryptographer.Encrypt(null, Cryptographer.EncryptionType.DES, this.key, this.vector);
        }

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        public void DESDecryptTest()
        {
            string data = "HCv368BmiLGqNYfQNF74mA==";
            string expected = "password";
            string actual = BusinessLogicLayer.Utilities.Cryptographer.Decrypt(data, Cryptographer.EncryptionType.DES, this.key, this.vector);
            Assert.AreEqual(expected, actual, "BusinessLogicLayer.Utilities.Cryptographer.Decrypt did not return the expected value.");
        }

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        [ExpectedException(typeof(ArgumentNullException))]
        public void DESDecryptTest1()
        {
            BusinessLogicLayer.Utilities.Cryptographer.Decrypt("password", Cryptographer.EncryptionType.DES, null, this.vector);
        }

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        [ExpectedException(typeof(ArgumentNullException))]
        public void DESDecryptTest2()
        {
            BusinessLogicLayer.Utilities.Cryptographer.Decrypt("password", Cryptographer.EncryptionType.DES, this.key, null);
        }

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        [ExpectedException(typeof(ArgumentNullException))]
        public void DESDecryptTest3()
        {
            BusinessLogicLayer.Utilities.Cryptographer.Decrypt(null, Cryptographer.EncryptionType.DES, this.key, this.vector);
        }

        #endregion DES Tests

        #region MD5 Tests

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        public void MD5EncryptTest()
        {
            string data = "password";
            string expected = "X03MO1qnZdYdgyfeuILPmQ==";
            string actual = BusinessLogicLayer.Utilities.Cryptographer.Encrypt(data, Cryptographer.EncryptionType.MD5, (string)null, (string)null);
            Assert.AreEqual(expected, actual, "BusinessLogicLayer.Utilities.Cryptographer.Encrypt did not return the expected value.");
        }

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        [ExpectedException(typeof(InvalidOperationException))]
        public void MD5DecryptTest()
        {
            BusinessLogicLayer.Utilities.Cryptographer.Decrypt("password", Cryptographer.EncryptionType.MD5, (string)null, (string)null);
        }

        #endregion MD5 Tests

        #region RC2 Tests

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        public void RC2EncryptTest()
        {
            string data = "password";
            string expected = "guxjV0T6wL3N+Oj0k3ijEg==";
            string actual = BusinessLogicLayer.Utilities.Cryptographer.Encrypt(data, Cryptographer.EncryptionType.RC2, this.key, this.vector);
            Assert.AreEqual(expected, actual, "BusinessLogicLayer.Utilities.Cryptographer.Encrypt did not return the expected value.");
        }

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        [ExpectedException(typeof(ArgumentNullException))]
        public void RC2EncryptTest1()
        {
            BusinessLogicLayer.Utilities.Cryptographer.Encrypt("password", Cryptographer.EncryptionType.RC2, null, this.vector);
        }

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        [ExpectedException(typeof(ArgumentNullException))]
        public void RC2EncryptTest2()
        {
            BusinessLogicLayer.Utilities.Cryptographer.Encrypt("password", Cryptographer.EncryptionType.RC2, this.key, null);
        }

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        [ExpectedException(typeof(ArgumentNullException))]
        public void RC2EncryptTest3()
        {
            BusinessLogicLayer.Utilities.Cryptographer.Encrypt(null, Cryptographer.EncryptionType.RC2, this.key, this.vector);
        }

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        public void RC2DecryptTest()
        {
            string data = "guxjV0T6wL3N+Oj0k3ijEg==";
            string expected = "password";
            string actual = BusinessLogicLayer.Utilities.Cryptographer.Decrypt(data, Cryptographer.EncryptionType.RC2, this.key, this.vector);
            Assert.AreEqual(expected, actual, "BusinessLogicLayer.Utilities.Cryptographer.Decrypt did not return the expected value.");
        }

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        [ExpectedException(typeof(ArgumentNullException))]
        public void RC2DecryptTest1()
        {
            BusinessLogicLayer.Utilities.Cryptographer.Decrypt("password", Cryptographer.EncryptionType.RC2, null, this.vector);
        }

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        [ExpectedException(typeof(ArgumentNullException))]
        public void RC2DecryptTest2()
        {
            BusinessLogicLayer.Utilities.Cryptographer.Decrypt("password", Cryptographer.EncryptionType.RC2, this.key, null);
        }

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        [ExpectedException(typeof(ArgumentNullException))]
        public void RC2DecryptTest3()
        {
            BusinessLogicLayer.Utilities.Cryptographer.Decrypt(null, Cryptographer.EncryptionType.RC2, this.key, this.vector);
        }

        #endregion RC2 Tests

        #region RSA Tests

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        [ExpectedException(typeof(ArgumentNullException))]
        public void RSAEncryptTest()
        {
            BusinessLogicLayer.Utilities.Cryptographer.Encrypt(string.Empty, Cryptographer.EncryptionType.RSA, (string)null, (string)null);
        }

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        [ExpectedException(typeof(ArgumentNullException))]
        public void RSADecryptTest1()
        {
            BusinessLogicLayer.Utilities.Cryptographer.Decrypt(string.Empty, Cryptographer.EncryptionType.RSA, (string)null, (string)null);
        }

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        public void RSAEncryptDecryptTest()
        {
            string data = "TimesheetId=123";
            string encrypted = BusinessLogicLayer.Utilities.Cryptographer.Encrypt(data, Cryptographer.EncryptionType.RSA, this.rsaPublicKey, null);
            string decrypted = BusinessLogicLayer.Utilities.Cryptographer.Decrypt(encrypted, Cryptographer.EncryptionType.RSA, this.rsaPrivateKey, null);
            Assert.AreEqual(data, decrypted, "Encrypt and Decrypt did not return the expected value.");
        }

        /// <summary>
        /// A test for CreateRSAPrivatePublicKeys (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        public void RSAKeysTest()
        {
            string privateKey, publicKey;
            BusinessLogicLayer.Utilities.Cryptographer.CreateRSAPrivatePublicKeys(out privateKey, out publicKey);
            Assert.IsNotNull(privateKey);
            Assert.IsNotNull(publicKey);
        }

        #endregion MD5 Tests

        #region SHA1 Tests

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        public void SHA1EncryptTest()
        {
            string data = "password";
            string expected = "W6ph5Mm5Pz8GgiULbPgzG37mj9g=";
            string actual = BusinessLogicLayer.Utilities.Cryptographer.Encrypt(data, Cryptographer.EncryptionType.SHA1, (string)null, (string)null);
            Assert.AreEqual(expected, actual, "BusinessLogicLayer.Utilities.Cryptographer.Encrypt did not return the expected value.");
        }

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        [ExpectedException(typeof(InvalidOperationException))]
        public void SHA1DecryptTest()
        {
            BusinessLogicLayer.Utilities.Cryptographer.Decrypt("password", Cryptographer.EncryptionType.SHA1, (string)null, (string)null);
        }

        #endregion SHA1 Tests

        #region Triple DES Tests

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        public void TripleDESEncryptTest()
        {
            string data = "password";
            string expected = "mcaai7TaxDrE3G2Nj3ZhlQ==";
            string actual = BusinessLogicLayer.Utilities.Cryptographer.Encrypt(data, Cryptographer.EncryptionType.TripleDES, "ShHhd8a08JhJiho98ayslcjh", this.vector);
            Assert.AreEqual(expected, actual, "BusinessLogicLayer.Utilities.Cryptographer.Encrypt did not return the expected value.");
        }

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        [ExpectedException(typeof(ArgumentNullException))]
        public void TripleDESEncryptTest1()
        {
            BusinessLogicLayer.Utilities.Cryptographer.Encrypt("password", Cryptographer.EncryptionType.TripleDES, null, this.vector);
        }

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        [ExpectedException(typeof(ArgumentNullException))]
        public void TripleDESEncryptTest2()
        {
            BusinessLogicLayer.Utilities.Cryptographer.Encrypt("password", Cryptographer.EncryptionType.TripleDES, this.key, null);
        }

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        [ExpectedException(typeof(ArgumentNullException))]
        public void TripleDESEncryptTest3()
        {
            BusinessLogicLayer.Utilities.Cryptographer.Encrypt(null, Cryptographer.EncryptionType.TripleDES, this.key, this.vector);
        }

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        public void TripleDESDecryptTest()
        {
            string data = "mcaai7TaxDrE3G2Nj3ZhlQ==";
            string expected = "password";
            string actual = BusinessLogicLayer.Utilities.Cryptographer.Decrypt(data, Cryptographer.EncryptionType.TripleDES, "ShHhd8a08JhJiho98ayslcjh", this.vector);
            Assert.AreEqual(expected, actual, "BusinessLogicLayer.Utilities.Cryptographer.Decrypt did not return the expected value.");
        }

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        [ExpectedException(typeof(ArgumentNullException))]
        public void TripleDESDecryptTest1()
        {
            BusinessLogicLayer.Utilities.Cryptographer.Decrypt("password", Cryptographer.EncryptionType.TripleDES, null, this.vector);
        }

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        [ExpectedException(typeof(ArgumentNullException))]
        public void TripleDESDecryptTest2()
        {
            BusinessLogicLayer.Utilities.Cryptographer.Decrypt("password", Cryptographer.EncryptionType.TripleDES, this.key, null);
        }

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        [ExpectedException(typeof(ArgumentNullException))]
        public void TripleDESDecryptTest3()
        {
            BusinessLogicLayer.Utilities.Cryptographer.Decrypt(null, Cryptographer.EncryptionType.TripleDES, this.key, this.vector);
        }

        /// <summary>
        /// A test for Encrypt (string, EncryptionType, key, vector)
        /// </summary>
        [TestMethod()]
        public void TripleDESDecryptTest4()
        {
            byte[] key;
            byte[] vector;
            BusinessLogicLayer.Utilities.Cryptographer.CreateTripleDESKeyVector(out key, out vector);
            string encrypted = BusinessLogicLayer.Utilities.Cryptographer.Encrypt("password", Cryptographer.EncryptionType.TripleDES, key, vector);
            string decrypted = BusinessLogicLayer.Utilities.Cryptographer.Decrypt(encrypted, Cryptographer.EncryptionType.TripleDES, key, vector);
            Assert.AreEqual(decrypted, "password");
        }

        #endregion Triple DES Tests
    }
}
