//-----------------------------------------------------------------------
// <copyright file="Activity.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that represents a Activity.</summary>
//-----------------------------------------------------------------------
namespace BusinessObjects
{
    using System;

    /// <summary>
    /// Class that represents a Activity.
    /// </summary>
    public class Activity
    {
        /// <summary>Unique Id of the Activity.</summary>
        public readonly long ActivityId;

        /// <summary>Unique Id of the JobCode.</summary>
        public readonly long JobCodeId;

        /// <summary>Disabled Date of Activity.</summary>
        public readonly DateTime? DisabledDateTime;

        /// <summary>Creation Date of Activity.</summary>
        public readonly DateTime CreationDateTime;

        /// <summary>Holds the activity name.</summary>
        private string name;

        /// <summary>Holds the Code.</summary>
        private string code;

        /// <summary>
        /// Initializes a new instance of the Activity class.
        /// </summary>
        /// <param name="activityId">Unique id of activity.</param>
        /// <param name="jobCodeId">Id of job code.</param>
        /// <param name="code">Activity Code.</param>
        /// <param name="creationDateTime">Creation date of activity.</param>
        /// <param name="disabledDateTime">Disabled date of activity.</param>
        /// <param name="name">Name of activity.</param>
        public Activity(long activityId, long jobCodeId, string code, DateTime creationDateTime, DateTime? disabledDateTime, string name)
        {
            this.ActivityId = activityId;
            this.JobCodeId = jobCodeId;
            this.code = code;
            this.CreationDateTime = creationDateTime;
            this.DisabledDateTime = disabledDateTime;
            this.Name = name;
        }

        /// <summary>Gets or sets name of Activity.</summary>
        public string Name
        {
            get { return this.name; }
            set { this.name = value; }
        }

        /// <summary>Gets or sets the Code.</summary>
        public string Code
        {
            get { return this.code; }
            set { this.code = value; }
        }
    }
}
