//-----------------------------------------------------------------------
// <copyright file="ActivityCollection.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that represents a ActivityCollection.</summary>
//-----------------------------------------------------------------------
namespace BusinessObjects.Collections
{
    using System.Collections.Generic;

    /// <summary>
    /// Class that represents a collection of Activities.
    /// </summary>
    public class ActivityCollection : List<Activity>
    {
        /// <summary>
        /// Returns the Activity from the list by its id.
        /// </summary>
        /// <param name="activityId">Id to search for.</param>
        /// <returns>The matching status.</returns>
        public Activity GetById(long activityId)
        {
            foreach (Activity activity in this)
            {
                if (activity.ActivityId == activityId)
                {
                    return activity;
                }
            }

            return null;
        }

        /// <summary>
        /// Returns the Activity from the list by its code.
        /// </summary>
        /// <param name="code">code to search for.</param>
        /// <returns>The matching status.</returns>
        public Activity GetByCode(string code)
        {
            foreach (Activity activity in this)
            {
                if (activity.Code == code)
                {
                    return activity;
                }
            }

            return null;
        }

        /// <summary>
        /// Returns the Activity from the list by its name.
        /// </summary>
        /// <param name="name">name to search for.</param>
        /// <returns>The matching status.</returns>
        public Activity GetByName(string name)
        {
            foreach (Activity activity in this)
            {
                if (activity.Name == name)
                {
                    return activity;
                }
            }

            return null;
        }
    }
}
