//-----------------------------------------------------------------------
// <copyright file="JobCodeCollection.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that represents a JobCodeCollection.</summary>
//-----------------------------------------------------------------------
namespace BusinessObjects.Collections
{
    using System.Collections.Generic;

    /// <summary>
    /// Class that represents a collection of Job Codes.
    /// </summary>
    public class JobCodeCollection : List<JobCode>
    {
        /// <summary>
        /// Returns the job code from the list by its id.
        /// </summary>
        /// <param name="jobCodeId">Id to search for.</param>
        /// <returns>The matching status.</returns>
        public JobCode GetById(long jobCodeId)
        {
            foreach (JobCode jobCode in this)
            {
                if (jobCode.JobCodeId == jobCodeId)
                {
                    return jobCode;
                }
            }

            return null;
        }

        /// <summary>
        /// Returns the job Code from the list by its code.
        /// </summary>
        /// <param name="code">code to search for.</param>
        /// <returns>The matching status.</returns>
        public JobCode GetByCode(string code)
        {
            foreach (JobCode jobCode in this)
            {
                if (jobCode.Code == code)
                {
                    return jobCode;
                }
            }

            return null;
        }

        /// <summary>
        /// Returns the job Code from the list by its name.
        /// </summary>
        /// <param name="name">name to search for.</param>
        /// <returns>The matching status.</returns>
        public JobCode GetByName(string name)
        {
            foreach (JobCode jobCode in this)
            {
                if (jobCode.Name == name)
                {
                    return jobCode;
                }
            }

            return null;
        }
    }
}