//-----------------------------------------------------------------------
// <copyright file="TimesheetAttendanceEntryCollection.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that represents a TimesheetAttendanceEntryCollection.</summary>
//-----------------------------------------------------------------------
namespace BusinessObjects.Collections
{
    using System;
    using System.Collections.Generic;

    /// <summary>
    /// Class that represents a collection of Timesheet Attendance Entries.
    /// </summary>
    [Serializable]
    public class TimesheetAttendanceEntryCollection : List<TimesheetAttendanceEntry>
    {
        /// <summary>
        /// Gets all entries for the date specified.
        /// </summary>
        /// <param name="date">Date to search for.</param>
        /// <returns>Collection with matching dates.</returns>
        public TimesheetAttendanceEntryCollection GetDateEntries(DateTime date)
        {
            TimesheetAttendanceEntryCollection collection = new TimesheetAttendanceEntryCollection();
            foreach (TimesheetAttendanceEntry entry in this)
            {
                if (entry.StartDateTime.Date == date.Date)
                {
                    collection.Add(entry);
                }
            }

            return collection;
        }

        /// <summary>
        /// Gets an entry with matching date and the correct index, if it exists.
        /// </summary>
        /// <param name="date">Date to search for.</param>
        /// <param name="index">Index to return.</param>
        /// <returns>Matching Entry ot null.</returns>
        public TimesheetAttendanceEntry GetEntry(DateTime date, int index)
        {
            TimesheetAttendanceEntryCollection collection = this.GetDateEntries(date);
            if (collection.Count > index)
            {
                return collection[index];
            }

            return null;
        }
    }
}