//-----------------------------------------------------------------------
// <copyright file="TimesheetCollection.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that represents a TimesheetCollection.</summary>
//-----------------------------------------------------------------------
namespace BusinessObjects.Collections
{
    using System;
    using System.Collections.Generic;

    /// <summary>
    /// Class that represents a collection of Timesheets.
    /// </summary>
    [Serializable]
    public class TimesheetCollection : List<Timesheet>
    {
        /// <summary>
        /// Gets the total number of pages the would be required to Show this collection.
        /// </summary>
        /// <param name="pageSize">The size of a single page.</param>
        /// <returns>Total pages required.</returns>
        public int GetTotalPages(int pageSize)
        {
            if (pageSize <= 0)
            {
                throw new ArgumentOutOfRangeException("pageSize");
            }

            int totalPages = this.Count / pageSize;
            if (this.Count % pageSize > 0)
            {
                totalPages++;
            }

            return totalPages;
        }

        /// <summary>
        /// Gets a collection that represents the page sepcified.
        /// </summary>
        /// <param name="pageSize">The size of a single page.</param>
        /// <param name="pageNumber">The number of the page. Must be greater than 0.</param>
        /// <returns>Collection for the page.</returns>
        public TimesheetCollection GetPage(int pageSize, int pageNumber)
        {
            if (pageSize <= 0)
            {
                throw new ArgumentOutOfRangeException("pageSize");
            }

            if (pageNumber <= 0)
            {
                throw new ArgumentOutOfRangeException("pageNumber");
            }

            TimesheetCollection result = new TimesheetCollection();
            if (this.Count > (pageSize * (pageNumber - 1)))
            {
                for (int i = 0; i < pageSize; i++)
                {
                    int index = (pageSize * (pageNumber - 1)) + i;
                    if (this.Count > index)
                    {
                        result.Add(this[index]);
                    }
                    else
                    {
                        break;
                    }
                }
            }

            return result;
        }
    }
}