//-----------------------------------------------------------------------
// <copyright file="TimesheetStatusCollection.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that represents a TimesheetStatusCollection.</summary>
//-----------------------------------------------------------------------
namespace BusinessObjects.Collections
{
    using System.Collections.Generic;

    /// <summary>
    /// Class that represents a collection of Timesheet Statuses.
    /// </summary>
    public class TimesheetStatusCollection : List<TimesheetStatus>
    {
        /// <summary>
        /// Returns the status from the list by its id.
        /// </summary>
        /// <param name="timesheetStatusId">Id to search for.</param>
        /// <returns>The matching status.</returns>
        public TimesheetStatus GetById(short timesheetStatusId)
        {
            foreach (TimesheetStatus status in this)
            {
                if (status.TimesheetStatusId == timesheetStatusId)
                {
                    return status;
                }
            }

            return null;
        }

        /// <summary>
        /// Removes an item from the list by id.
        /// </summary>
        /// <param name="timesheetStatusId">Item to remove.</param>
        public void RemoveById(short timesheetStatusId)
        {
            for (int i = 0; i < this.Count; i++)
            {
                TimesheetStatus status = this[i] as TimesheetStatus;
                if (status.TimesheetStatusId == timesheetStatusId)
                {
                    this.RemoveAt(i);
                    break;
                }
            }
        }
    }
}