//-----------------------------------------------------------------------
// <copyright file="UserCollection.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that represents a UserCollection.</summary>
//-----------------------------------------------------------------------
namespace BusinessObjects.Collections
{
    using System;
    using System.Collections.Generic;

    /// <summary>
    /// Class that represents a collection of Users.
    /// </summary>
    [Serializable]
    public class UserCollection : List<User>
    {
        /// <summary>
        /// Gets the total number of pages the would be required to Show this collection.
        /// </summary>
        /// <param name="pageSize">The size of a single page. Must be greater than 0.</param>
        /// <returns>Total pages required.</returns>
        public int GetTotalPages(int pageSize)
        {
            if (pageSize <= 0)
            {
                throw new ArgumentOutOfRangeException("pageSize");
            }

            int totalPages = this.Count / pageSize;
            if (this.Count % pageSize > 0)
            {
                totalPages++;
            }

            return totalPages;
        }

        /// <summary>
        /// Gets a collection that represents the page sepcified.
        /// </summary>
        /// <param name="pageSize">The size of a single page. Must be greater than 0.</param>
        /// <param name="pageNumber">The number of the page. Must be greater than 0.</param>
        /// <returns>Collection of users for the page.</returns>
        public UserCollection GetPage(int pageSize, int pageNumber)
        {
            if (pageSize <= 0)
            {
                throw new ArgumentOutOfRangeException("pageSize");
            }

            if (pageNumber <= 0)
            {
                throw new ArgumentOutOfRangeException("pageNumber");
            }

            UserCollection users = new UserCollection();
            if (this.Count > (pageSize * (pageNumber - 1)))
            {
                for (int i = 1; i <= pageSize; i++)
                {
                    if (this.Count >= (pageSize * (pageNumber - 1)) + i)
                    {
                        users.Add(this[i]);
                    }
                    else
                    {
                        break;
                    }
                }
            }

            return users;
        }
    }
}