//-----------------------------------------------------------------------
// <copyright file="Entry.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that represensts a Entry.</summary>
//-----------------------------------------------------------------------
namespace BusinessObjects
{
    using System;

    /// <summary>
    /// Class that represents a Entry.
    /// </summary>
    public class Entry
    {
        /// <summary>Unique Id of Entry.</summary>
        public readonly long EntryId;

        /// <summary>Id of user the entry belongs to.</summary>
        public readonly long UserId;

        /// <summary>Id of Entry Status.</summary>
        public readonly short EntryStatusId;

        /// <summary>Id of user who last changed the status of the entry.</summary>
        public readonly long StatusChangerUserId;

        /// <summary>Date the status was changed.</summary>
        public readonly DateTime StatusChangeDate;

        /// <summary>Creation Date of entry.</summary>
        public readonly DateTime CreationDate;

        /// <summary>Holds Id of job code.</summary>
        private long jobCodeId;

        /// <summary>Holds Id of Activity.</summary>
        private long activityId;

        /// <summary>Holds the Start Time of entry.</summary>
        private DateTime startDateTime;

        /// <summary>Holds the End Time of entry.</summary>
        private DateTime endDateTime;

        /// <summary>
        /// Initializes a new instance of the Entry class.
        /// </summary>
        /// <param name="entryId">Unique id of entry.</param>
        /// <param name="userId">Id of user.</param>
        /// <param name="jobCodeId">Id of job Code.</param>
        /// <param name="activityId">Id of activity code.</param>
        /// <param name="entryStatusId">Id of entry status id.</param>
        /// <param name="startDateTime">Start date of entry.</param>
        /// <param name="endDateTime">End Date of entry.</param>
        /// <param name="statusChangerUserId">Id of user who changed the entry.</param>
        /// <param name="creationDate">Date the entry was created.</param>
        /// <param name="statusChangeDate">Date of when the status was last changed.</param>
        public Entry(long entryId, long userId, long jobCodeId, long activityId, short entryStatusId, DateTime startDateTime, DateTime endDateTime, long statusChangerUserId, DateTime creationDate, DateTime statusChangeDate)
        {
            this.EntryId = entryId;
            this.UserId = userId;
            this.jobCodeId = jobCodeId;
            this.activityId = activityId;
            this.EntryStatusId = entryStatusId;
            this.startDateTime = startDateTime;
            this.endDateTime = endDateTime;
            this.StatusChangerUserId = statusChangerUserId;
            this.CreationDate = creationDate;
            this.StatusChangeDate = statusChangeDate;
        }

        /// <summary>Gets or sets Id of job code.</summary>
        public long JobCodeId
        {
            get { return this.jobCodeId; }
            set { this.jobCodeId = value; }
        }

        /// <summary>Gets or sets Id of Activity.</summary>
        public long ActivityId
        {
            get { return this.activityId; }
            set { this.activityId = value; }
        }

        /// <summary>Gets or sets the Start Time of entry.</summary>
        public DateTime StartDateTime
        {
            get { return this.startDateTime; }
            set { this.startDateTime = value; }
        }

        /// <summary>Gets or sets the End Time of entry.</summary>
        public DateTime EndDateTime
        {
            get { return this.endDateTime; }
            set { this.endDateTime = value; }
        }
    }
}
