//-----------------------------------------------------------------------
// <copyright file="JobCode.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that represents a JobCode.</summary>
//-----------------------------------------------------------------------
namespace BusinessObjects
{
    using System;

    /// <summary>
    /// Class that represents a JobCode.
    /// </summary>
    public class JobCode
    {
        /// <summary>Unique Id of the JobCode.</summary>
        public readonly long JobCodeId;

        /// <summary>Unique Id of the Organisation.</summary>
        public readonly int OrganisationId;

        /// <summary>Disabled Date of user.</summary>
        public readonly DateTime? DisabledDateTime;

        /// <summary>Creation Date of user.</summary>
        public readonly DateTime CreationDateTime;

        /// <summary>Holds the JobCode name.</summary>
        private string name;

        /// <summary>Holds the Code.</summary>
        private string code;

        /// <summary>
        /// Initializes a new instance of the JobCode class.
        /// </summary>
        /// <param name="jobCodeId">Unique id of Job Code.</param>
        /// <param name="organisationId">Id of organisation.</param>
        /// <param name="code">The Job Code.</param>
        /// <param name="name">Name of Job Code.</param>
        /// <param name="creationDateTime">Creation date of Job Code.</param>
        /// <param name="disabledDateTime">Disabled date of job code.</param>
        public JobCode(long jobCodeId, int organisationId, string code, string name, DateTime creationDateTime, DateTime? disabledDateTime)
        {
            this.JobCodeId = jobCodeId;
            this.OrganisationId = organisationId;
            this.code = code;
            this.Name = name;
            this.CreationDateTime = creationDateTime;
            this.DisabledDateTime = disabledDateTime;
        }

        /// <summary>Gets or sets name of JobCode.</summary>
        public string Name
        {
            get { return this.name; }
            set { this.name = value; }
        }

        /// <summary>Gets or sets the Code.</summary>
        public string Code
        {
            get { return this.code; }
            set { this.code = value; }
        }
    }
}
