//-----------------------------------------------------------------------
// <copyright file="Organisation.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that represensts a Organisation.</summary>
//-----------------------------------------------------------------------
namespace BusinessObjects
{
    using System;

    /// <summary>
    /// Class that represents an Organisation.
    /// </summary>
    public class Organisation
    {
        /// <summary>Unique Id of Organisation.</summary>
        public readonly int OrganisationId;

        /// <summary>Disabled Date of user.</summary>
        public readonly DateTime? DisabledDateTime;

        /// <summary>Creation Date of user.</summary>
        public readonly DateTime CreationDateTime;

        /// <summary>Holds the Organisation name.</summary>
        private string name;

        /// <summary>
        /// Initializes a new instance of the Organisation class.
        /// </summary>
        /// <param name="organisationId">Unique Id of organisation.</param>
        /// <param name="name">Name of Job Organisation.</param>
        /// <param name="creationDateTime">Creation date of Organisation.</param>
        /// <param name="disabledDateTime">Disabled date of Organisation.</param>
        public Organisation(int organisationId, string name, DateTime creationDateTime, DateTime? disabledDateTime)
        {
            this.OrganisationId = organisationId;
            this.Name = name;
            this.CreationDateTime = creationDateTime;
            this.DisabledDateTime = disabledDateTime;
        }

        /// <summary>Gets or sets name of Organisation.</summary>
        public string Name
        {
            get { return this.name; }
            set { this.name = value; }
        }
    }
}
