//-----------------------------------------------------------------------
// <copyright file="Timesheet.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that represensts a Timesheet.</summary>
//-----------------------------------------------------------------------
namespace BusinessObjects
{
    using System;

    /// <summary>
    /// Class that represents a Timesheet.
    /// </summary>
    [Serializable]
    public class Timesheet
    {
        /// <summary>Unique Id of Timesheet.</summary>
        public readonly long TimesheetId;

        /// <summary>Id of User.</summary>
        public readonly long UserId;

        /// <summary>Id of TimesheetStatus.</summary>
        public readonly short TimesheetStatusId;

        /// <summary>Id of status Changer User.</summary>
        public readonly long StatusChangerUserId;

        /// <summary>Date of the timesheet's weekend.</summary>
        public readonly DateTime WeekEndDate;

        /// <summary>Holds the status Change Description.</summary>
        public readonly string StatusChangeDescription;

        /// <summary>When the timesheet was created.</summary>
        public readonly DateTime CreationDateTime;

        /// <summary>When the status of the timesheet was changed.</summary>
        public readonly DateTime StatusChangeDateTime;

        /// <summary>
        /// Initializes a new instance of the Timesheet class.
        /// </summary>
        /// <param name="timesheetId">Unique Id of Timesheet.</param>
        /// <param name="userId">Id of User.</param>
        /// <param name="timesheetStatusId">Id of TimesheetStatus.</param>
        /// <param name="statusChangerUserId">Id of status Changer User.</param>
        /// <param name="weekEndDate">Date of the timesheet's weekend.</param>
        /// <param name="statusChangeDescription">Holds the status Change Description.</param>
        /// <param name="creationDateTime">When the timesheet was created.</param>
        /// <param name="statusChangeDateTime">When the status of the timesheet was changed.</param>
        public Timesheet(long timesheetId, long userId, short timesheetStatusId, long statusChangerUserId, DateTime weekEndDate, string statusChangeDescription, DateTime creationDateTime, DateTime statusChangeDateTime)
        {
            this.TimesheetId = timesheetId;
            this.UserId = userId;
            this.TimesheetStatusId = timesheetStatusId;
            this.StatusChangerUserId = statusChangerUserId;
            this.WeekEndDate = weekEndDate;
            this.StatusChangeDescription = statusChangeDescription;
            this.CreationDateTime = creationDateTime;
            this.StatusChangeDateTime = statusChangeDateTime;
        }

        /// <summary>
        /// Initializes a new instance of the Timesheet class.
        /// </summary>
        /// <param name="userId">Id of user.</param>
        /// <param name="weekEndDate">Date of the timesheet's weekend.</param>
        public Timesheet(long userId, DateTime weekEndDate)
        {
            this.UserId = userId;
            this.WeekEndDate = weekEndDate;
        }

        /// <summary>
        /// Initializes a new instance of the Timesheet class.
        /// </summary>
        /// <param name="timesheetId">Unique Id of Timesheet.</param>
        /// <param name="userId">Id of user.</param>
        /// <param name="weekEndDate">Date of the timesheet's weekend.</param>
        public Timesheet(long timesheetId, long userId, DateTime weekEndDate)
        {
            this.TimesheetId = timesheetId;
            this.UserId = userId;
            this.WeekEndDate = weekEndDate;
        }
    }
}
