//-----------------------------------------------------------------------
// <copyright file="TimesheetActivityEntry.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that represensts a TimesheetActivityEntry.</summary>
//-----------------------------------------------------------------------
namespace BusinessObjects
{
    using System;

    /// <summary>
    /// Class that represents a Timesheet Activity Entry.
    /// </summary>
    [Serializable]
    public class TimesheetActivityEntry
    {
        /// <summary>Unique Id of TimesheetActivityEntry.</summary>
        public readonly long TimesheetActivityEntryId;

        /// <summary>Id of Timesheet.</summary>
        public readonly long TimesheetId;

        /// <summary>Creation Date of entry.</summary>
        public readonly DateTime CreationDateTime;

        /// <summary>Holds Id of Activity.</summary>
        public readonly long ActivityId;

        /// <summary>Holds the number of hours.</summary>
        public readonly decimal Hours;

        /// <summary>The description of the entry.</summary>
        public readonly string Description;

        /// <summary>Holds the date of the activity.</summary>
        public readonly DateTime Date;

        /// <summary>
        /// Initializes a new instance of the TimesheetActivityEntry class.
        /// </summary>
        /// <param name="timesheetActivityEntryId">Unique id of timesheet Activity Entry.</param>
        /// <param name="timesheetId">Id of timesheet.</param>
        /// <param name="activityId">Id of activity code.</param>
        /// <param name="hours">Number of ours for entry.</param>
        /// <param name="description">Activity description.</param>
        /// <param name="date">Date for entry.</param>
        /// <param name="creationDateTime">Date the entry was created.</param>
        public TimesheetActivityEntry(long timesheetActivityEntryId, long timesheetId, long activityId, decimal hours, string description, DateTime date, DateTime creationDateTime)
        {
            this.TimesheetActivityEntryId = timesheetActivityEntryId;
            this.TimesheetId = timesheetId;
            this.ActivityId = activityId;
            this.Hours = hours;
            this.Description = description;
            this.Date = date.Date;
            this.CreationDateTime = creationDateTime;
        }

        /// <summary>
        /// Initializes a new instance of the TimesheetActivityEntry class.
        /// </summary>
        /// <param name="activityId">Id of activity code.</param>
        /// <param name="hours">Number of ours for entry.</param>
        /// <param name="description">Description of activity.</param>
        /// <param name="date">Date for entry.</param>
        public TimesheetActivityEntry(long activityId, decimal hours, string description, DateTime date)
        {
            this.ActivityId = activityId;
            this.Hours = hours;
            this.Description = description;
            this.Date = date.Date;
        }
    }
}
