//-----------------------------------------------------------------------
// <copyright file="TimesheetAttendanceEntry.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that represensts a TimesheetAttendanceEntry.</summary>
//-----------------------------------------------------------------------
namespace BusinessObjects
{
    using System;

    /// <summary>
    /// Class that represents a Timesheet Attendance Entry.
    /// </summary>
    [Serializable]
    public class TimesheetAttendanceEntry
    {
        /// <summary>Unique Id of TimesheetAttendanceEntry.</summary>
        public readonly long TimesheetAttendanceEntryId;

        /// <summary>Id of Timesheet.</summary>
        public readonly long TimesheetId;

        /// <summary>Creation Date of entry.</summary>
        public readonly DateTime CreationDateTime;

        /// <summary>Start Date of entry.</summary>
        private DateTime startDateTime;

        /// <summary>End Date of entry.</summary>
        private DateTime endDateTime;

        /// <summary>
        /// Initializes a new instance of the TimesheetAttendanceEntry class.
        /// </summary>
        /// <param name="timesheetAttendanceEntryId">Unique id of timesheet Attendance Entry.</param>
        /// <param name="timesheetId">Id of timesheet.</param>
        /// <param name="startDateTime">Start Date Time of attendance.</param>
        /// <param name="endDateTime">Enda Date Time of attendance.</param>
        /// <param name="creationDateTime">Date the entry was created.</param>
        public TimesheetAttendanceEntry(long timesheetAttendanceEntryId, long timesheetId, DateTime startDateTime, DateTime endDateTime, DateTime creationDateTime)
        {
            this.TimesheetAttendanceEntryId = timesheetAttendanceEntryId;
            this.TimesheetId = timesheetId;
            this.StartDateTime = startDateTime;
            this.EndDateTime = endDateTime;
            this.CreationDateTime = creationDateTime;
        }

        /// <summary>
        /// Initializes a new instance of the TimesheetAttendanceEntry class.
        /// </summary>
        /// <param name="startDateTime">Start Date Time of attendance.</param>
        /// <param name="endDateTime">Enda Date Time of attendance.</param>
        public TimesheetAttendanceEntry(DateTime startDateTime, DateTime endDateTime)
        {
            this.StartDateTime = startDateTime;
            this.EndDateTime = endDateTime;
        }

        /// <summary>Gets or sets Start Date Time.</summary>
        public DateTime StartDateTime
        {
            get { return this.startDateTime; }
            set { this.startDateTime = value; }
        }

        /// <summary>Gets or sets the end date time.</summary>
        public DateTime EndDateTime
        {
            get { return this.endDateTime; }
            set { this.endDateTime = value; }
        }
    }
}
