//-----------------------------------------------------------------------
// <copyright file="User.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that represensts a user.</summary>
//-----------------------------------------------------------------------
namespace BusinessObjects
{
    using System;

    /// <summary>
    /// Class that represents a user.
    /// </summary>
    public class User
    {
        #region Public Read Only Members

        /// <summary>Unique Id of user.</summary>
        public readonly long UserId;

        /// <summary>Password of user.</summary>
        public readonly string Password;

        /// <summary>Activation Date of user.</summary>
        public readonly DateTime? ActivationDateTime;

        /// <summary>Disabled Date of user.</summary>
        public readonly DateTime? DisabledDateTime;

        /// <summary>Creation Date of user.</summary>
        public readonly DateTime CreationDateTime;

        #endregion Public Read Only Members

        #region Private Members

        /// <summary>Holds Employee id of user.</summary>
        private string employeeId;

        /// <summary>Holds Email address of user.</summary>
        private string email;

        /// <summary>Holds Gender Id of user.</summary>
        private byte genderId;

        /// <summary>Holds Role Id of user.</summary>
        private short roleId;

        /// <summary>Holds Firstname of user.</summary>
        private string firstname;

        /// <summary>Holds Surname of user.</summary>
        private string surname;

        /// <summary>Holds OrganisationId of user.</summary>
        private int? organisationId;

        /// <summary>Holds ApproverUserId of user.</summary>
        private long? approverUserId;

        #endregion Private Members

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the User class.
        /// </summary>
        /// <param name="userId">Unique id of user.</param>
        /// <param name="employeeId">Id of the employee.</param>
        /// <param name="email">Email of user.</param>
        /// <param name="genderId">Id of gender.</param>
        /// <param name="roleId">Id of role.</param>
        /// <param name="firstname">Firstname of user.</param>
        /// <param name="surname">Surname of user.</param>
        /// <param name="password">Password od user.</param>
        /// <param name="organisationId">Organisation of user.</param>
        /// <param name="approverUserId">Approver of user.</param>
        /// <param name="activationDateTime">Activation date of user.</param>
        /// <param name="disabledDateTime">Disbaled date of user.</param>
        /// <param name="creationDateTime">Creation date of user.</param>
        public User(
            long userId, 
            string employeeId,
            string email, 
            byte genderId, 
            short roleId, 
            string firstname, 
            string surname, 
            string password, 
            int? organisationId, 
            long? approverUserId,
            DateTime? activationDateTime,
            DateTime? disabledDateTime,
            DateTime creationDateTime)
        {
            this.UserId = userId;
            this.EmployeeId = employeeId;
            this.Email = email;
            this.GenderId = genderId;
            this.RoleId = roleId;
            this.Firstname = firstname;
            this.Surname = surname;
            this.Password = password;
            this.OrganisationId = organisationId;
            this.ApproverUserId = approverUserId;
            this.ActivationDateTime = activationDateTime;
            this.DisabledDateTime = disabledDateTime;
            this.CreationDateTime = creationDateTime;
        }

        #endregion Constructors

        #region Public Properties

        /// <summary>Gets or sets employee id of user.</summary>
        public string EmployeeId
        {
            get { return this.employeeId; }
            set { this.employeeId = value; }
        }

        /// <summary>Gets or sets Email address of user.</summary>
        public string Email
        {
            get { return this.email; }
            set { this.email = value; }
        }

        /// <summary>Gets or sets Gender Id of user.</summary>
        public byte GenderId
        {
            get { return this.genderId; }
            set { this.genderId = value; }
        }

        /// <summary>Gets or sets Role Id of user.</summary>
        public short RoleId
        {
            get { return this.roleId; }
            set { this.roleId = value; }
        }

        /// <summary>Gets or sets Firstname of user.</summary>
        public string Firstname
        {
            get { return this.firstname; }
            set { this.firstname = value; }
        }

        /// <summary>Gets or sets Surname of user.</summary>
        public string Surname
        {
            get { return this.surname; }
            set { this.surname = value; }
        }

        /// <summary>Gets or sets OrganisationId of user.</summary>
        public int? OrganisationId
        {
            get { return this.organisationId; }
            set { this.organisationId = value; }
        }

        /// <summary>Gets or sets ApproverUserId of user.</summary>
        public long? ApproverUserId
        {
            get { return this.approverUserId; }
            set { this.approverUserId = value; }
        }

        /// <summary>
        /// Gets the full name.
        /// </summary>
        public string FullName
        {
            get { return this.Firstname + " " + this.Surname + "(" + this.EmployeeId + ")"; }
        }

        #endregion Public Properties
    }
}
