//-----------------------------------------------------------------------
// <copyright file="Message.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds abstract class that represents a generic Message.</summary>
//-----------------------------------------------------------------------
namespace CommunicationManager
{
    /// <summary>Interface that represents a generic Message.</summary>
    public abstract class Message
    {
        #region Private Members

        /// <summary>Holds the priority of the message.</summary>
        private MessagePriority priority;

        #endregion Private Members

        #region Constructor

        /// <summary>
        /// Initializes a new instance of the Message class.
        /// </summary>
        /// <param name="priority">The priority of the message.</param>
        public Message(MessagePriority priority)
        {
            this.priority = priority;
        }

        #endregion Constructor

        #region Public Enums

        /// <summary>
        /// Holds the Message Priorities.
        /// </summary>
        public enum MessagePriority
        {
            /// <summary>High Message Priority.</summary>
            High,

            /// <summary>Medium Message Priority.</summary>
            Medium,

            /// <summary>Low Message Priority.</summary>
            Low
        }

        #endregion Public Enums

        #region Public Properties

        /// <summary>Gets the priority of the message.</summary>
        public MessagePriority Priority
        {
            get { return this.priority; }
        }

        #endregion Public Properties

        #region Public Abstract Methods

        /// <summary>Methods that handles the message object.</summary>
        public abstract void HandleMessage();

        #endregion Public Abstract Methods
    }
}
