//-----------------------------------------------------------------------
// <copyright file="MessageQueue.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that represents a messaeg queue.</summary>
//-----------------------------------------------------------------------
namespace CommunicationManager
{
    using System.Collections.Generic;

    /// <summary>
    /// Class that represents a message queue.
    /// </summary>
    internal class MessageQueue
    {
        #region Private Members

        /// <summary>Holds queue of messages that need to be handled.</summary>
        private List<Message> messageQueue;

        /// <summary>Represents the lock for the message queue.</summary>
        private object messageQueueLock;

        #endregion Private Members

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the MessageQueue class.
        /// </summary>
        public MessageQueue()
        {
            this.messageQueueLock = new object();
            this.messageQueue = new List<Message>();  
        }

        #endregion Constructors

        #region Public Properties

        /// <summary>Gets the queue size.</summary>
        public int Count
        {
            get 
            {
                lock (this.messageQueueLock)
                {
                    return this.messageQueue.Count;
                }
            }
        }

        #endregion Public Properties

        #region Public Methods

        /// <summary>
        /// Adds a message to the Message queue.
        /// </summary>
        /// <param name="message">Message to add to queue.</param>
        public void Enqueue(Message message)
        {
            lock (this.messageQueueLock)
            {
                this.messageQueue.Add(message);
            }
        }

        /// <summary>
        /// Removes and returns a message of the queue.
        /// </summary>
        /// <returns>The message of the queue or null if the queue is empty.</returns>
        public Message Dequeue()
        {
            Message message = null;
            lock (this.messageQueueLock)
            {
                if (this.messageQueue.Count > 0)
                {
                    message = this.messageQueue[0];
                    this.messageQueue.RemoveAt(0);
                }
            }

            return message;
        }

        #endregion Public Methods
    }
}
