//-----------------------------------------------------------------------
// <copyright file="MessageStatusHandler.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds abstract class that represents a generic Message Status Handler.</summary>
//-----------------------------------------------------------------------
namespace CommunicationManager
{
    using System;

    /// <summary>
    /// Class that represents a generic Message Status Handler
    /// </summary>
    public abstract class MessageStatusHandler
    {
        /// <summary>Handles successfull completion of message task.</summary>
        /// <param name="message">Message that was handled.</param>
        public abstract void HandleSuccess(Message message);

        /// <summary>Handles error that has occurred.</summary>
        /// <param name="ex">The exception the occurred.</param>
        public abstract void HandleError(Exception ex);

        /// <summary>Handles error of message task.</summary>
        /// <param name="message">Message that failed.</param>
        /// <param name="ex">The exception the occurred.</param>
        public abstract void HandleError(Message message, Exception ex);
    }
}
