//-----------------------------------------------------------------------
// <copyright file="EntryStatusDataObject.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that allows Entry StatusD ata to be manipultaed.</summary>
//-----------------------------------------------------------------------
namespace DataAccessLayer
{
    using System;
    using BusinessObjects;
    using BusinessObjects.Collections;
    using BusinessObjects.Filters;

    /// <summary>
    /// Class that allows Entry Status Data to be manipultaed.
    /// </summary>
    public static class EntryStatusDataObject
    {
        /// <summary>
        /// Adds new Entry Status.
        /// </summary>
        /// <param name="name">Name of Entry Status.</param>
        /// <returns>Id of new Entry Status.</returns>
        public static short AddEntryStatus(string name)
        {
            try
            {
                return DataObject.DataAccessor.AddEntryStatus(name);
            }
            catch (Exception ex)
            {
                DataObject.DataAccessor.HandleException(ex);
                throw;
            }
        }

        /// <summary>
        /// Updates existing Entry Status.
        /// </summary>
        /// <param name="entryStatus">Entry Status to update.</param>
        public static void UpdateEntryStatus(EntryStatus entryStatus)
        {
            try
            {
                DataObject.DataAccessor.UpdateEntryStatus(entryStatus);
            }
            catch (Exception ex)
            {
                DataObject.DataAccessor.HandleException(ex);
                throw;
            }
        }

        /// <summary>
        /// Deletes existing Entry Status.
        /// </summary>
        /// <param name="entryStatusId">Id of Entry Status to delete.</param>
        public static void DeleteEntryStatus(short entryStatusId)
        {
            try
            {
                DataObject.DataAccessor.DeleteEntryStatus(entryStatusId);
            }
            catch (Exception ex)
            {
                DataObject.DataAccessor.HandleException(ex);
                throw;
            }
        }

        /// <summary>
        /// Gets a collection of Entry Statuses that match the filter.
        /// </summary>
        /// <param name="filter">Filter to use when retrieving data.</param>
        /// <returns>Collection containing elements that match the filter.</returns>
        public static EntryStatusCollection GetEntryStatuses(EntryStatusFilter filter)
        {
            try
            {
                return DataObject.DataAccessor.GetEntryStatuses(filter);
            }
            catch (Exception ex)
            {
                DataObject.DataAccessor.HandleException(ex);
                throw;
            }
        }
    }
}
