//-----------------------------------------------------------------------
// <copyright file="CommonConstants.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that represents a CommonConstants.</summary>
//-----------------------------------------------------------------------
namespace TimesheetWebApplication.App_Code
{
    using System;
    using System.Configuration;
    
    /// <summary>Class that hold constants.</summary>
    public static class CommonConstants
    {
        /// <summary>
        /// Holds the different timesheet views available.
        /// </summary>
        public enum TimesheetView
        {
            /// <summary>My timesheet views.</summary>
            MyView,

            /// <summary>Others timesheet views.</summary>
            Others
        }

        /// <summary>
        /// Holds session veriable names.
        /// </summary>
        public static class SessionVariables
        {
            /// <summary>Holds user id</summary>
            public const string UserId = "UserId";

            /// <summary>Holds Timesheets Filter.</summary>
            public const string TimesheetsFilter = "TimesheetsFilter";

            /// <summary>Holds My Timesheets Filter.</summary>
            public const string MyTimesheetsFilter = "MyTimesheetsFilter";
        }

        /// <summary>
        /// Holds system configuration values
        /// </summary>
        public static class Configuration
        {
            /// <summary>
            /// Gets the session timeout in mins.
            /// </summary>
            public static int SessionTimeoutMins
            {
                get { return Convert.ToInt32(ConfigurationManager.AppSettings["SessionTimeoutMins"]); }
            }

            /// <summary>
            /// Gets the date format.
            /// </summary>
            public static string DateFormat
            {
                get { return ConfigurationManager.AppSettings["DateFormat"]; }
            }

            /// <summary>
            /// Gets the datetime format.
            /// </summary>
            public static string DateTimeFormat
            {
                get { return ConfigurationManager.AppSettings["DateTimeFormat"]; }
            }

            /// <summary>
            /// Gets the date regex.
            /// </summary>
            public static string DateRegex
            {
                get { return ConfigurationManager.AppSettings["DateRegex"]; }
            }

            /// <summary>
            /// Gets the default buffer used when searching by a date period.
            /// </summary>
            public static int TimesheetsSearchDefaultDaysBuffer
            {
                get { return Convert.ToInt32(ConfigurationManager.AppSettings["TimesheetsSearchDefaultDaysBuffer"]); }
            }

            /// <summary>
            /// Gets the maximum number of rows that shold be returned from a result.
            /// </summary>
            public static int MaxRowsReturned
            {
                get { return Convert.ToInt32(ConfigurationManager.AppSettings["MaxRowsReturned"]); }
            }

            /// <summary>
            /// Gets the maximum number of buttons to display in the page control.
            /// </summary>
            public static int MaxPagingButtons
            {
                get { return Convert.ToInt32(ConfigurationManager.AppSettings["MaxPagingButtons"]); }
            }

            /// <summary>
            /// Gets the page size of the gridview/repeaters.
            /// </summary>
            public static int PageSize
            {
                get { return Convert.ToInt32(ConfigurationManager.AppSettings["PageSize"]); }
            }

            /// <summary>Gets the RSA Private Key</summary>
            public static string PrivateEncryptionKey
            {
                get { return "<RSAKeyValue><Modulus>xY7DvF4RIHF0AUlnWwdsvkzviVbQNjUIACuOeHlsKRhfeddA/0mZouEhUNwBfByQE0ddBGsy6r0mTYnhtaAFzdtTtpdVc+3x/o7lnzdubQM2ecVO2jG6C+YgU1ny32SPwJwMiXLAa1uTIt9zP9kqDjCAsG9OglArdqc1hNLtnMk=</Modulus><Exponent>AQAB</Exponent><P>7pQEPB5+//5LolsB0txb8Ed51+9dyGtL2oSieiJPZfvV11tWfHVHQQhwV4a2DwLN7omKZZaVWAmRUE5umOl2XQ==</P><Q>0/vo+YD0ldEXkGBeFA1LglnpAxDFqEvgpqpFnKxqD3Y3i11o/lTNQSuhwU3Uj95RYg3v5845KEX9Ky726lBBXQ==</Q><DP>PQQcBSgjgOMPgulVkREMbmpJTiGI0a4nSy6qwyOtPL7olNhmSRRRcd9vo+LvAu3Lrxr8Czk03rwrrucwP+lNfQ==</DP><DQ>QxnleD0aruW96MSoYv6GXV+qg37mokxKc1dIq7xj4jsQf/v0hTVAt5VhIXhKhbPg3QH+Y8kCjL4C0o2OOUNoPQ==</DQ><InverseQ>YPGOFQolADE3ku0C4No6iTJLxpvtoLtaqk5tN00J8xgQehAoijoukobfv2E61EZpNOKzQ8qQSHJDquEudamzQA==</InverseQ><D>YZlDN/cc7PM/xTb3WbBUV7t4h1gdKvqOBk9+ZiROfArveCkQkk5RGXexVtop3Z/aybtyx7ESCYgCuUHKAUmaM5d0ejPMj2T7S9d/g6IKxfPEw/pjgsPd4HFlF4GnBRqZiKZkr53R1Fw1K/uEArJVv7Vc6IJei5e/43Zd0xI0JJE=</D></RSAKeyValue>"; }
            }

            /// <summary>Gets the RSA Public Key</summary>
            public static string PublicEncryptionKey
            {
                get { return "<RSAKeyValue><Modulus>xY7DvF4RIHF0AUlnWwdsvkzviVbQNjUIACuOeHlsKRhfeddA/0mZouEhUNwBfByQE0ddBGsy6r0mTYnhtaAFzdtTtpdVc+3x/o7lnzdubQM2ecVO2jG6C+YgU1ny32SPwJwMiXLAa1uTIt9zP9kqDjCAsG9OglArdqc1hNLtnMk=</Modulus><Exponent>AQAB</Exponent></RSAKeyValue>"; }
            }

            /// <summary>Gets the default width of the dynamic textbox.</summary>
            public static int DefaultDynamicTextBoxWidthPixels
            {
                get { return Convert.ToInt32(ConfigurationManager.AppSettings["DefaultDynamicTextBoxWidthPixels"]); }
            }

            /// <summary>
            /// Gets the maximum number of rows to diaply in the timesheetOVerview control.
            /// </summary>
            public static int TimesheetsOverviewRowCount
            {
                get { return Convert.ToInt32(ConfigurationManager.AppSettings["TimesheetsOverviewRowCount"]); }
            }

            /// <summary>
            /// Gets the Smtp Host.
            /// </summary>
            public static string SmtpHost
            {
                get { return ConfigurationManager.AppSettings["SmtpHost"]; }
            }

            /// <summary>
            /// Gets the Smtp Port.
            /// </summary>
            public static int SmtpPort
            {
                get { return Convert.ToInt32(ConfigurationManager.AppSettings["SmtpPort"]); }
            }

            /// <summary>
            /// Gets the Admin Email.
            /// </summary>
            public static string AdminEmail
            {
                get { return ConfigurationManager.AppSettings["AdminEmail"]; }
            }

            /// <summary>
            /// Gets the App Error Email.
            /// </summary>
            public static string AppErrorEmail
            {
                get { return ConfigurationManager.AppSettings["AppErrorEmail"]; }
            }

            /// <summary>
            /// Gets the Contact Us Email.
            /// </summary>
            public static string ContactUsEmail
            {
                get { return ConfigurationManager.AppSettings["ContactUsEmail"]; }
            }

            /// <summary>
            /// Gets the Site Name.
            /// </summary>
            public static string SiteName
            {
                get { return ConfigurationManager.AppSettings["SiteName"]; }
            }
        }

        /// <summary>
        /// Holds css styles
        /// </summary>
        public static class CssStyles
        {
            /// <summary>Holds InOutTextbox Class Name</summary>
            public const string InOutTextboxClassName = "InOutTextbox";

            /// <summary>Holds InOutWeekend Class Name</summary>
            public const string InOutWeekendTextboxClassName = "InOutWeekendTextbox";

            /// <summary>Holds InOutTextboxError Class Name</summary>
            public const string InOutTextboxErrorClassName = "InOutTextboxError";

            /// <summary>Holds ActivityDescriptionTextbox Class Name.</summary>
            public const string ActivityDescriptionTextboxClassName = "ActivityDescriptionTextbox";

            /// <summary>Holds JobCodeDropDownList Class Name.</summary>
            public const string JobCodeDropDownListClassName = "JobCodeDropDownList";

            /// <summary>Holds ActivityDropDownList Class Name.</summary>
            public const string ActivityDropDownListClassName = "ActivityDropDownList";

            /// <summary>Holds AddInOutRowButton Class Name.</summary>
            public const string AddInOutRowButtonClassName = "AddInOutRowButton";

            /// <summary>Holds RemoveInOutRowButton Class Name.</summary>
            public const string RemoveInOutRowButtonClassName = "RemoveInOutRowButton";

            /// <summary>Holds AddActivityRowButton Class Name.</summary>
            public const string AddActivityRowButtonClassName = "AddActivityRowButton";

            /// <summary>Holds RemoveActivityRowButton Class Name.</summary>
            public const string RemoveActivityRowButtonClassName = "RemoveActivityRowButton";

            /// <summary>Holds the InRow Class Name.</summary>
            public const string InRowClassName = "InRow";

            /// <summary>Holds the OutRow Class Name.</summary>
            public const string OutRowClassName = "OutRow";

            /// <summary>Holds the Activity Class Name.</summary>
            public const string ActivityRowClassName = "ActivityRow";

            /// <summary>Holds the In Text Class Name.</summary>
            public const string InTextClassName = "InTextClassName";

            /// <summary>Holds the In Text Class Name.</summary>
            public const string OutTextClassName = "OutTextClassName";

            /// <summary>Holds the Sum Error Class Name.</summary>
            public const string SumErrorClassName = "SumErrorClassName";
        }

        /// <summary>
        /// Holds Query String veriable names.
        /// </summary>
        public static class QueryStringVariables
        {
            /// <summary>Holds Request</summary>
            public const string Request = "Request";

            /// <summary>Holds timesheet id</summary>
            public const string TimesheetId = "TimesheetId";

            /// <summary>Holds the organisation id.</summary>
            public const string OrganisationId = "OrganisationId";

            /// <summary>Holds the user id.</summary>
            public const string UserId = "UserId";

            /// <summary>Holds the Timesheet Status Id.</summary>
            public const string TimesheetStatusId = "TimesheetStatusId";

            /// <summary>Holds the Timesheet View.</summary>
            public const string TimesheetView = "TimesheetView";
        }

        /// <summary>
        /// Holds ViewState veriable names.
        /// </summary>
        public static class ViewStateVariables
        {
            /// <summary>Holds Timesheet</summary>
            public const string Timesheet = "Timesheet";

            /// <summary>Holds Timesheet Table</summary>
            public const string TimesheetTable = "TimesheetTable";
        }

        /// <summary>
        /// Class that holds urls.
        /// </summary>
        public static class Urls
        {
            /// <summary>Default aspx</summary>
            public const string Default = "~/Default.aspx";

            /// <summary>Error aspx</summary>
            public const string Error = "~/Error.aspx";

            /// <summary>Clock aspx</summary>
            public const string Clock = "~/Clock.aspx";

            /// <summary>
            /// Holds urls in secure folder
            /// </summary>
            public static class Secure
            {
                /// <summary>Change Password aspx</summary>
                public const string ChangePassword = "~/Secure/ChangePassword.aspx";

                /// <summary>Default aspx</summary>
                public const string Default = "~/Secure/Default.aspx";

                /// <summary>Timesheet aspx</summary>
                public const string Timesheet = "~/Secure/Timesheet.aspx";

                /// <summary>Timesheets aspx</summary>
                public const string Timesheets = "~/Secure/Timesheets.aspx";

                /// <summary>
                /// Holds urls in admin folder
                /// </summary>
                public static class Admin
                {
                    /// <summary>Activities aspx</summary>
                    public const string Activities = "~/Secure/Admin/Activities.aspx";

                    /// <summary>Create Activity aspx</summary>
                    public const string CreateActivity = "~/Secure/Admin/CreateActivity.aspx";

                    /// <summary>Create JobCode aspx</summary>
                    public const string CreateJobCode = "~/Secure/Admin/CreateJobCode.aspx";

                    /// <summary>Create Organisation aspx</summary>
                    public const string CreateOrganisation = "~/Secure/Admin/CreateOrganisation.aspx";

                    /// <summary>Create Role aspx</summary>
                    public const string CreateRole = "~/Secure/Admin/CreateRole.aspx";

                    /// <summary>Create Timesheet Status aspx</summary>
                    public const string CreateTimesheetStatus = "~/Secure/Admin/CreateTimesheetStatus.aspx";

                    /// <summary>Create User aspx</summary>
                    public const string CreateUser = "~/Secure/Admin/CreateUser.aspx";

                    /// <summary>Default aspx</summary>
                    public const string Default = "~/Secure/Admin/Default.aspx";

                    /// <summary>Edit User aspx</summary>
                    public const string EditUser = "~/Secure/Admin/EditUser.aspx";

                    /// <summary>Job Codes aspx</summary>
                    public const string JobCodes = "~/Secure/Admin/JobCodes.aspx";

                    /// <summary>Organisations aspx</summary>
                    public const string Organisations = "~/Secure/Admin/Organisations.aspx";

                    /// <summary>Roles aspx</summary>
                    public const string Roles = "~/Secure/Admin/Roles.aspx";

                    /// <summary>Timesheet Statuses aspx</summary>
                    public const string TimesheetStatuses = "~/Secure/Admin/TimesheetStatuses.aspx";

                    /// <summary>Users aspx</summary>
                    public const string Users = "~/Secure/Admin/Users.aspx";
                }
            }
        }

        /// <summary>
        /// Holds the Email file names.
        /// </summary>
        public static class EmailBodyFiles
        {
            /// <summary>The forgotten password email format.</summary>
            public const string ForgottenPasswordEmail = "~/App_Data/Emails/ForgottenPasswordEmail.txt";

            /// <summary>The Timesheet Submitted email format.</summary>
            public const string TimesheetSubmittedEmail = "~/App_Data/Emails/TimesheetSubmittedEmail.txt";

            /// <summary>The Timesheet Approved email format.</summary>
            public const string TimesheetApprovedEmail = "~/App_Data/Emails/TimesheetApprovedEmail.txt";

            /// <summary>The Timesheet Declined email format.</summary>
            public const string TimesheetDeclinedEmail = "~/App_Data/Emails/TimesheetDeclinedEmail.txt";
        }
    }
}
