//-----------------------------------------------------------------------
// <copyright file="TimesheetTableError.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that TimesheetTableError.</summary>
//-----------------------------------------------------------------------
namespace TimesheetWebApplication.App_Code
{
    using System;

    /// <summary>
    /// Class used to represent TimesheetTableError table.
    /// </summary>
    public class TimesheetTableError
    {
        #region Private Members

        /// <summary>Holds row type.</summary>
        private RowType row;

        /// <summary>Holds error types.</summary>
        private ErrorType error;

        /// <summary>Holds optional date;</summary>
        private DateTime? date;

        #endregion Private Members

        /// <summary>
        /// Initializes a new instance of the TimesheetTableError class.
        /// </summary>
        /// <param name="row">The row type.</param>
        /// <param name="error">The error type.</param>
        public TimesheetTableError(RowType row, ErrorType error)
        {
            this.row = row;
            this.error = error;
        }

        /// <summary>
        /// Initializes a new instance of the TimesheetTableError class.
        /// </summary>
        /// <param name="row">The row type.</param>
        /// <param name="error">The error type.</param>
        /// <param name="date">Date of error.</param>
        public TimesheetTableError(RowType row, ErrorType error, DateTime date)
        {
            this.row = row;
            this.error = error;
            this.date = date;
        }

        #region Enums

        /// <summary>The row types an error can occur for.</summary>
        public enum RowType
        {
            /// <summary>AttendanceIn Row Type</summary>
            AttendanceIn,

            /// <summary>AttendanceOut Row Type</summary>
            AttendanceOut,

            /// <summary>Activity Row Type.</summary>
            Activity
        }

        /// <summary>
        /// The error types of the timesheet.
        /// </summary>
        public enum ErrorType
        {
            /// <summary>InvalidFormat Error Type.</summary>
            InvalidFormat,

            /// <summary>Incorrect range</summary>
            IncorrectRange,

            /// <summary>Incorrect Total range</summary>
            IncorrectTotal,

            /// <summary>Missong Value</summary>
            MissingValue,

            /// <summary>Missing Activity value.</summary>
            MissingActivity,

            /// <summary>Missing Hours error type.</summary>
            MissingHours
        }

        #endregion Enums

        #region Public Properties

        /// <summary>Gets the row type.</summary>
        public RowType Row
        {
            get { return this.row; }
        }

        /// <summary>Gets the Error type.</summary>
        public ErrorType Error
        {
            get { return this.error; }
        }

        /// <summary>Gets the Error date.</summary>
        public DateTime? Date
        {
            get { return this.date; }
        }

        #endregion Public Properties
    }
}
