//-----------------------------------------------------------------------
// <copyright file="ViewStateManager.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that manages ViewState.</summary>
//-----------------------------------------------------------------------
namespace TimesheetWebApplication.App_Code
{
    using System;
    using System.Web.UI;
    using System.Web.UI.WebControls;

    /// <summary>
    /// Class that manages View State.
    /// </summary>
    public class ViewStateManager
    {
        #region Private Members

        /// <summary>Holds viewstate details.</summary>
        private StateBag viewstate;

        #endregion Private Members

        #region Constructor

        /// <summary>
        /// Initializes a new instance of the ViewStateManager class.
        /// </summary>
        /// <param name="viewstate">StateBag object conatining current viewstate.</param>
        public ViewStateManager(StateBag viewstate)
        {
            if (viewstate == null)
            {
                throw new ArgumentNullException("viewstate");
            }

            this.viewstate = viewstate;
        }

        #endregion Constructor

        #region Public Methods

        /// <summary>
        /// Gets a value indicating whether timesheet table is in viewstate.
        /// </summary>
        public bool HasTimesheetTable
        {
            get
            {
                try
                {
                    if (this.viewstate[CommonConstants.ViewStateVariables.TimesheetTable] == null)
                    {
                        return false;
                    }

                    TimesheetTable timesheetTable = (TimesheetTable)this.viewstate[CommonConstants.ViewStateVariables.TimesheetTable];
                    return true;
                }
                catch
                {
                    return false;
                }
            }
        }

        /// <summary>
        /// Gets or sets the timesheet table.
        /// </summary>
        public TimesheetTable TimesheetTable
        {
            get
            {
                if (this.viewstate[CommonConstants.ViewStateVariables.TimesheetTable] != null)
                {
                    return this.viewstate[CommonConstants.ViewStateVariables.TimesheetTable] as TimesheetTable;
                }

                return null;
            }

            set
            {
                this.viewstate[CommonConstants.ViewStateVariables.TimesheetTable] = value;
            }
        }

        #endregion Public Methods
    }
}
