//-----------------------------------------------------------------------
// <copyright file="ContactUs.aspx.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that represents a ContactUs.</summary>
//-----------------------------------------------------------------------
namespace TimesheetWebApplication
{
    using System;
    using System.Web.UI.WebControls;
    using TimesheetWebApplication.App_Code;

    /// <summary>
    /// Class that represents ContactUs page.
    /// </summary>
    public partial class ContactUs : BasePage
    {
        #region Protected Methods

        /// <summary>
        /// Event Handler for on page load.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!this.IsPostBack)
            {
                this.PopulatePage();
            }
        }

        /// <summary>
        /// Event Handler for SendMessageButton click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void SendMessageButton_Clicked(object sender, EventArgs e)
        {
            try
            {
                string email = null;
                if (this.User.Identity.IsAuthenticated)
                {
                    email = this.User.Identity.Name;
                }
                else
                {
                    email = this.EmailTextBox.Text;
                }

                MailManager.SendContactUsMessage(this.SubjectList.SelectedValue, this.MessageTextBox.Text, email, this);
                this.PopulatePage();
                this.SuccessMessage(Resources.Main.MessageSent);
            }
            catch
            {
                this.AddErrorMessage(Resources.Main.MessageSendingError);
            }
        }

        #endregion Protected Methods

        #region Private Methods

        /// <summary>
        /// Populates the page.
        /// </summary>
        private void PopulatePage()
        {
            this.SubjectList.Items.Clear();
            this.SubjectList.Items.Add(BasePage.NullItem);
            this.SubjectList.Items.Add(new ListItem(Resources.Main.Complaint, Resources.Main.Complaint));
            this.SubjectList.Items.Add(new ListItem(Resources.Main.Suggestion, Resources.Main.Suggestion));
            this.SubjectList.Items.Add(new ListItem(Resources.Main.Error, Resources.Main.Error));
            this.SubjectList.Items.Add(new ListItem(Resources.Main.Other, Resources.Main.Other));

            this.MessageTextBox.Text = string.Empty;
            this.EmailTextBox.Text = string.Empty;

            if (this.User.Identity.IsAuthenticated)
            {
                this.EmailDiv.Visible = false;
            }
            else
            {
                this.EmailDiv.Visible = true;
            }
        }

        #endregion Private Methods
    }
}
