//-----------------------------------------------------------------------
// <copyright file="Activities.aspx.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that represents a Activities page.</summary>
//-----------------------------------------------------------------------
namespace TimesheetWebApplication.Secure.Admin
{
    using System;
    using System.Data;
    using System.Web.UI.WebControls;
    using BusinessLogicLayer;
    using BusinessObjects.Collections;
    using TimesheetWebApplication.App_Code;
    using TimesheetWebApplication.WebUserControls;

    /// <summary>
    /// Class that represents Activities page.
    /// </summary>
    public partial class Activities : AdminPage
    {
        #region Protected Methods

        /// <summary>
        /// Event Handler for on page load.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void Page_Load(object sender, EventArgs e)
        {
        }

        /// <summary>
        /// Event Handler for on SearchButton click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void SearchButton_Clicked(object sender, EventArgs e)
        {
            this.PopulateActivitiesRepeater();
        }

        /// <summary>
        /// Event Handler for on DeleteActivity click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void DeleteActivity_Clicked(object sender, EventArgs e)
        {   
            try
            {
                long id = Convert.ToInt64((sender as LinkButton).CommandArgument);
                BusinessLogicLayer.ActivityManager.Instance.DeleteActivity(id);
                this.PopulateActivitiesRepeater();
            }
            catch
            {
                this.AddErrorMessage(Resources.Main.ActivityDeletionError);
            }   
        }

        /// <summary>
        /// Event Handler for on DisableActivity click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void DisableActivity_Clicked(object sender, EventArgs e)
        {
            try
            {
                long id = Convert.ToInt64((sender as LinkButton).CommandArgument);
                BusinessLogicLayer.ActivityManager.Instance.DisableActivity(id);
                this.PopulateActivitiesRepeater();
            }
            catch
            {
            }
        }

        /// <summary>
        /// Event Handler for on EnableActivity click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void EnableActivity_Clicked(object sender, EventArgs e)
        {
            try
            {
                long id = Convert.ToInt64((sender as LinkButton).CommandArgument);
                BusinessLogicLayer.ActivityManager.Instance.EnableActivity(id);
                this.PopulateActivitiesRepeater();
            }
            catch
            {
            }
        }

        /// <summary>
        /// Event Handler for on CancelButton click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void CancelButton_Clicked(object sender, EventArgs e)
        {
            Response.Redirect(CommonConstants.Urls.Secure.Admin.Default);
        }

        /// <summary>
        /// Event Handler for on CancelButton click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void CreateActivityButton_Clicked(object sender, EventArgs e)
        {
            Response.Redirect(CommonConstants.Urls.Secure.Admin.CreateActivity);
        }

        #endregion Protected Methods

        #region Private Methods

        /// <summary>
        /// Populates the Timesheets Tab Panel.
        /// </summary>
        private void PopulateActivitiesRepeater()
        {
            this.ActivitiesRepeater.DataSource = this.CreateActivitiesDataTable();
            this.ActivitiesRepeater.DataBind();
        }

        /// <summary>
        /// Creates a datatable for the timesheets repeater.
        /// </summary>
        /// <returns>Table with activity data.</returns>
        private DataTable CreateActivitiesDataTable()
        {
            DataTable result = new DataTable();
            result.Columns.Add("Activity Id", typeof(long));
            result.Columns.Add("Activity Code", typeof(string));
            result.Columns.Add("Job Code", typeof(string));
            result.Columns.Add("Name", typeof(string));
            result.Columns.Add("Creation Date", typeof(DateTime));
            result.Columns.Add("Disabled Date", typeof(DateTime));
            result.Columns.Add("Enabled", typeof(bool));

            BusinessObjects.Filters.ActivityFilter filter = new BusinessObjects.Filters.ActivityFilter();
            filter.JobCodeId = this.ActivityFilterWebUserControl.JobCodeId;
            ActivityCollection activities = ActivityManager.Instance.GetActivities(filter);

            foreach (BusinessObjects.Activity activity in activities)
            {
                DataRow row = result.NewRow();
                row["Activity Id"] = activity.ActivityId;
                row["Activity Code"] = activity.Code;
                row["Job Code"] = JobCodeManager.Instance.GetJobCode(activity.JobCodeId).Name;
                row["Name"] = activity.Name;
                row["Creation Date"] = activity.CreationDateTime;
                row["Enabled"] = !activity.DisabledDateTime.HasValue;
                if (activity.DisabledDateTime.HasValue)
                {
                    row["Disabled Date"] = activity.DisabledDateTime.Value;
                }

                result.Rows.Add(row);
            }

            return result;
        }

        #endregion Private Methods
    }
}
