//-----------------------------------------------------------------------
// <copyright file="CreateJobCode.aspx.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that represents a CreateJobCode page.</summary>
//-----------------------------------------------------------------------
namespace TimesheetWebApplication.Secure.Admin
{
    using System;
    using System.Web.UI.WebControls;
    using BusinessLogicLayer;
    using BusinessObjects;
    using BusinessObjects.Collections;
    using BusinessObjects.Filters;
    using TimesheetWebApplication.App_Code;

    /// <summary>
    /// Class used to represent the CreateJobCode page.
    /// </summary>
    public partial class CreateJobCode : AdminPage
    {
        #region Protected Methods

        /// <summary>
        /// Event Handler for on page load.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!this.IsPostBack)
            {
                this.Populate();
            }
        }

        /// <summary>
        /// Event Handler for CreateJobCodeButton Click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void CreateJobCodeButton_Clicked(object sender, EventArgs e)
        {
            try
            {
                if (this.IsUserAdministrator)
                {
                    long jobCodeId = JobCodeManager.Instance.AddJobCode(
                        this.CodeTextBox.Text,
                        this.NameTextBox.Text,
                        Convert.ToInt32(this.OrganisationList.SelectedValue));
                }
                else
                {
                    if (!this.IsUserInOrganisation)
                    {
                        long jobCodeId = JobCodeManager.Instance.AddJobCode(
                        this.CodeTextBox.Text,
                        this.NameTextBox.Text,
                        Convert.ToInt32(this.OrganisationList.SelectedValue));
                    }
                    else
                    {
                        long jobCodeId = JobCodeManager.Instance.AddJobCode(
                        this.CodeTextBox.Text,
                        this.NameTextBox.Text,
                        this.UserOrganisationId);
                    }
                }

                this.SuccessMessage(Resources.Main.JobCodeCreated);
            }
            catch
            {
                this.AddErrorMessage(Resources.Main.JobCodeCreationError);
            }
        }

        /// <summary>
        /// Event Handler for CancelButton Click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void CancelButton_Clicked(object sender, EventArgs e)
        {
            Response.Redirect(CommonConstants.Urls.Secure.Admin.Default);
        }

        #endregion Protected Methods

        #region Private Methods

        /// <summary>
        /// Populates the current page.
        /// </summary>
        private void Populate()
        {
            this.CodeTextBox.Text = string.Empty;
            this.NameTextBox.Text = string.Empty;
            if (this.IsUserAdministrator)
            {
                this.OrganisationSection.Visible = true;
                this.PopulateOrganisationList();
            }
            else
            {
                if (!this.IsUserInOrganisation)
                {
                    this.OrganisationSection.Visible = true;
                    this.PopulateOrganisationList();
                }
                else
                {
                    this.OrganisationSection.Visible = false;
                }
            }
        }

        /// <summary>
        /// Populates the Organisation List.
        /// </summary>
        private void PopulateOrganisationList()
        {
            OrganisationCollection orgs = OrganisationManager.Instance.GetOrganisations(null);
            this.OrganisationList.Items.Clear();
            this.OrganisationList.Items.Add(BasePage.NullItem);
            foreach (Organisation org in orgs)
            {
                this.OrganisationList.Items.Add(new ListItem(org.Name, org.OrganisationId.ToString()));
            }
        }

        #endregion Private Methods
    }
}
