//-----------------------------------------------------------------------
// <copyright file="Roles.aspx.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that represents a Roles page.</summary>
//-----------------------------------------------------------------------
namespace TimesheetWebApplication.Secure.Admin
{
    using System;
    using System.Data;
    using System.Web.UI.WebControls;
    using BusinessLogicLayer;
    using BusinessObjects.Collections;
    using TimesheetWebApplication.App_Code;
    using TimesheetWebApplication.WebUserControls;

    /// <summary>
    /// Class used to represent the Roles page.
    /// </summary>
    public partial class Roles : AdminPage
    {
        #region Protected Methods

        /// <summary>
        /// Event Handler for on page load.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!this.IsPostBack)
            {
                this.PopulateRolesRepeater();
            }
        }

        /// <summary>
        /// Event Handler for on DeleteRole click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void DeleteRole_Clicked(object sender, EventArgs e)
        {
            try
            {
                short id = Convert.ToInt16((sender as LinkButton).CommandArgument);
                BusinessLogicLayer.RoleManager.Instance.DeleteRole(id);
                this.PopulateRolesRepeater();
            }
            catch
            {
                this.AddErrorMessage(Resources.Main.RoleDeletionError);
            }
        }

        /// <summary>
        /// Event Handler for on CancelButton click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void CancelButton_Clicked(object sender, EventArgs e)
        {
            Response.Redirect(CommonConstants.Urls.Secure.Admin.Default);
        }

        /// <summary>
        /// Event Handler for on CreateRoleButton click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void CreateRoleButton_Clicked(object sender, EventArgs e)
        {
            Response.Redirect(CommonConstants.Urls.Secure.Admin.CreateRole);
        }

        #endregion Protected Methods

        #region Private Methods

        /// <summary>
        /// Populates the Organisations repeater.
        /// </summary>
        private void PopulateRolesRepeater()
        {
            this.RolesRepeater.DataSource = this.CreateRolesDataTable();
            this.RolesRepeater.DataBind();
        }

        /// <summary>
        /// Creates a datatable for the Roles repeater.
        /// </summary>
        /// <returns>Table with Organisations data.</returns>
        private DataTable CreateRolesDataTable()
        {
            DataTable result = new DataTable();
            result.Columns.Add("Role Id", typeof(short));
            result.Columns.Add("Name", typeof(string));

            RoleCollection roles = RoleManager.Instance.GetRoles(null);
            foreach (BusinessObjects.Role role in roles)
            {
                DataRow row = result.NewRow();
                row["Role Id"] = role.RoleId;
                row["Name"] = role.Name;
                result.Rows.Add(row);
            }

            return result;
        }

        #endregion Private Methods
    }
}
