//-----------------------------------------------------------------------
// <copyright file="TimesheetStatuses.aspx.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that represents a TimesheetStatuses page.</summary>
//-----------------------------------------------------------------------
namespace TimesheetWebApplication.Secure.Admin
{
    using System;
    using System.Data;
    using System.Web.UI.WebControls;
    using BusinessLogicLayer;
    using BusinessObjects.Collections;
    using TimesheetWebApplication.App_Code;
    using TimesheetWebApplication.WebUserControls;

    /// <summary>
    /// Class used to represent the TimesheetStatuses page.
    /// </summary>
    public partial class TimesheetStatuses : AdminPage
    {
        #region Protected Methods

        /// <summary>
        /// Event Handler for on page load.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!this.IsPostBack)
            {
                this.PopulateTimesheetStatusesRepeater();
            }
        }

        /// <summary>
        /// Event Handler for on DeleteTimesheetStatus click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void DeleteTimesheetStatus_Clicked(object sender, EventArgs e)
        {
            try
            {
                short id = Convert.ToInt16((sender as LinkButton).CommandArgument);
                BusinessLogicLayer.TimesheetStatusManager.Instance.DeleteTimesheetStatus(id);
                this.PopulateTimesheetStatusesRepeater();
            }
            catch
            {
                this.AddErrorMessage(Resources.Main.TimesheetStatusDeletionError);
            }
        }

        /// <summary>
        /// Event Handler for on CancelButton click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void CancelButton_Clicked(object sender, EventArgs e)
        {
            Response.Redirect(CommonConstants.Urls.Secure.Admin.Default);
        }

        /// <summary>
        /// Event Handler for on CreateTimesheetStatusButton click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void CreateTimesheetStatusButton_Clicked(object sender, EventArgs e)
        {
            Response.Redirect(CommonConstants.Urls.Secure.Admin.CreateTimesheetStatus);
        }

        #endregion Protected Methods

        #region Private Methods

        /// <summary>
        /// Populates the Timesheet Statuses repeater.
        /// </summary>
        private void PopulateTimesheetStatusesRepeater()
        {
            this.TimesheetStatusesRepeater.DataSource = this.CreateTimesheetStatusesDataTable();
            this.TimesheetStatusesRepeater.DataBind();
        }

        /// <summary>
        /// Creates a datatable for the Timesheet Statuses repeater.
        /// </summary>
        /// <returns>Table with Timesheet Statuses data.</returns>
        private DataTable CreateTimesheetStatusesDataTable()
        {
            DataTable result = new DataTable();
            result.Columns.Add("Timesheet Status Id", typeof(short));
            result.Columns.Add("Name", typeof(string));

            TimesheetStatusCollection statuses = TimesheetStatusManager.Instance.GetTimesheetStatuses(null);
            foreach (BusinessObjects.TimesheetStatus status in statuses)
            {
                DataRow row = result.NewRow();
                row["Timesheet Status Id"] = status.TimesheetStatusId;
                row["Name"] = status.Name;
                result.Rows.Add(row);
            }

            return result;
        }

        #endregion Private Methods
    }
}
