//-----------------------------------------------------------------------
// <copyright file="Users.aspx.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that represents a Users page.</summary>
//-----------------------------------------------------------------------
namespace TimesheetWebApplication.Secure.Admin
{
    using System;
    using System.Data;
    using System.Web.UI.WebControls;
    using BusinessLogicLayer;
    using BusinessObjects.Collections;
    using TimesheetWebApplication.App_Code;
    using TimesheetWebApplication.WebUserControls;

    /// <summary>
    /// Class used to represent the Users page.
    /// </summary>
    public partial class Users : AdminPage
    {
        #region Protected Methods

        /// <summary>
        /// Event Handler for on page load.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void Page_Load(object sender, EventArgs e)
        {
        }

        /// <summary>
        /// Event Handler for on SearchButton click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void SearchButton_Clicked(object sender, EventArgs e)
        {
            this.PopulateUsersRepeater();
        }

        /// <summary>
        /// Event Handler for on DeleteUser click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void DeleteUser_Clicked(object sender, EventArgs e)
        {
            try
            {
                long id = Convert.ToInt64((sender as LinkButton).CommandArgument);
                BusinessLogicLayer.UserManager.Instance.DeleteUser(id);
                this.PopulateUsersRepeater();
            }
            catch
            {
                this.AddErrorMessage(Resources.Main.UserDeletionError);
            }
        }

        /// <summary>
        /// Event Handler for on ActivateUser click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void ActivateUser_Clicked(object sender, EventArgs e)
        {
            try
            {
                long id = Convert.ToInt64((sender as LinkButton).CommandArgument);
                BusinessLogicLayer.UserManager.Instance.ActivateUser(id);
                this.PopulateUsersRepeater();
            }
            catch
            {
            }
        }

        /// <summary>
        /// Event Handler for on DeactivateUser click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void DeactivateUser_Clicked(object sender, EventArgs e)
        {
            try
            {
                long id = Convert.ToInt64((sender as LinkButton).CommandArgument);
                BusinessLogicLayer.UserManager.Instance.DeactivateUser(id);
                this.PopulateUsersRepeater();
            }
            catch
            {
            }
        }

        /// <summary>
        /// Event Handler for on EnableUser click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void EnableUser_Clicked(object sender, EventArgs e)
        {
            try
            {
                long id = Convert.ToInt64((sender as LinkButton).CommandArgument);
                BusinessLogicLayer.UserManager.Instance.EnableUser(id);
                this.PopulateUsersRepeater();
            }
            catch
            {
            }
        }

        /// <summary>
        /// Event Handler for on DisabledUser click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void DisableUser_Clicked(object sender, EventArgs e)
        {
            try
            {
                long id = Convert.ToInt64((sender as LinkButton).CommandArgument);
                BusinessLogicLayer.UserManager.Instance.DisableUser(id);
                this.PopulateUsersRepeater();
            }
            catch
            {
            }
        }

        /// <summary>
        /// Event Handler for on ResetPassword click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void ResetPassword_Clicked(object sender, EventArgs e)
        {
            try
            {
                long id = Convert.ToInt64((sender as LinkButton).CommandArgument);
                string newPassword = BusinessLogicLayer.UserManager.Instance.ResetPassword(id);
                this.SuccessMessage(Resources.Main.NewPasswordIs + " " + newPassword);
                this.PopulateUsersRepeater();
            }
            catch
            {
            }
        }

        /// <summary>
        /// Event Handler for on Mimic click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void Mimic_Clicked(object sender, EventArgs e)
        {
            try
            {
                long id = Convert.ToInt64((sender as LinkButton).CommandArgument);
                if (Global.CreateTicket(this.Page, UserManager.Instance.GetUser(id).Email, false, CommonConstants.Configuration.SessionTimeoutMins) == true)
                {
                    Response.Redirect(CommonConstants.Urls.Secure.Default);
                }
            }
            catch
            {
            }
        }

        /// <summary>
        /// Event Handler for on CancelButton click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void CancelButton_Clicked(object sender, EventArgs e)
        {
            Response.Redirect(CommonConstants.Urls.Secure.Admin.Default);
        }

        /// <summary>
        /// Event Handler for on CreateUserButton click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void CreateUserButton_Clicked(object sender, EventArgs e)
        {
            Response.Redirect(CommonConstants.Urls.Secure.Admin.CreateUser);
        }

        #endregion Protected Methods

        #region Private Methods

        /// <summary>
        /// Populates the Timesheets Tab Panel.
        /// </summary>
        private void PopulateUsersRepeater()
        {
            this.UsersRepeater.DataSource = this.CreateUsersDataTable();
            this.UsersRepeater.DataBind();
        }

        /// <summary>
        /// Creates a datatable for the users repeater.
        /// </summary>
        /// <returns>Table with users data.</returns>
        private DataTable CreateUsersDataTable()
        {
            DataTable result = new DataTable();
            result.Columns.Add("User Id", typeof(long));
            result.Columns.Add("Email", typeof(string));
            result.Columns.Add("Name", typeof(string));
            result.Columns.Add("Gender", typeof(string));
            result.Columns.Add("Creation Date", typeof(DateTime));
            result.Columns.Add("Activation Date", typeof(DateTime));
            result.Columns.Add("Disabled Date", typeof(DateTime));
            result.Columns.Add("Enabled", typeof(bool));
            result.Columns.Add("Activated", typeof(bool));
            result.Columns.Add("EditUserUrl", typeof(string));

            BusinessObjects.Filters.UserFilter filter = new BusinessObjects.Filters.UserFilter();
            filter.GenderId = this.UserFilterWebUserControl.GenderId;
            filter.OrganisationId = this.UserFilterWebUserControl.OrganisationId;
            filter.RoleId = this.UserFilterWebUserControl.RoleId;
            filter.User = this.UserFilterWebUserControl.User;
            filter.Approver = this.UserFilterWebUserControl.Approver;
            filter.MaxRecords = CommonConstants.Configuration.MaxRowsReturned;
            UserCollection users = UserManager.Instance.GetUsers(filter);

            foreach (BusinessObjects.User user in users)
            {
                DataRow row = result.NewRow();
                QueryStringManager manager = new QueryStringManager();

                row["User Id"] = user.UserId;
                row["Email"] = user.Email;
                row["Name"] = user.FullName;
                row["Gender"] = user.GenderId;
                row["Creation Date"] = user.CreationDateTime;

                row["Activated"] = user.ActivationDateTime.HasValue;
                if (user.ActivationDateTime.HasValue)
                {
                    row["Activation Date"] = user.ActivationDateTime.Value;
                }

                row["Enabled"] = !user.DisabledDateTime.HasValue;
                if (user.DisabledDateTime.HasValue)
                {
                    row["Disabled Date"] = user.DisabledDateTime.Value;
                }

                manager.Clear();
                manager.Add(CommonConstants.QueryStringVariables.UserId, user.UserId.ToString());
                row["EditUserUrl"] = QueryStringManager.AddValueToUrl(
                    CommonConstants.Urls.Secure.Admin.EditUser,
                    CommonConstants.QueryStringVariables.Request,
                    manager.Encrypt());

                result.Rows.Add(row);
            }

            return result;
        }

        #endregion Private Methods
    }
}
