//-----------------------------------------------------------------------
// <copyright file="ChangePassword.aspx.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that represents the Change Password page.</summary>
//-----------------------------------------------------------------------
namespace TimesheetWebApplication.Secure
{
    using System;
    using System.Web;
    using System.Web.Security;
    using BusinessLogicLayer;
    using BusinessObjects;
    using TimesheetWebApplication.App_Code;

    /// <summary>
    /// Class that represents ChangePassword page.
    /// </summary>
    public partial class ChangePassword : SecurePage
    {
        #region Protected Methods

        /// <summary>
        /// Event Handler for on page load.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void Page_Load(object sender, EventArgs e)
        {
        }

        /// <summary>
        /// Event Handler for when Change Password Button is clicked.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void ChangePasswordButton_Clicked(object sender, EventArgs e)
        {
            if (this.NewPasswordTextbox.Text != this.ConfirmNewPasswordTextbox.Text)
            {
                // Passwords do not match.
                this.ErrorLabel.InnerText = Resources.Main.NewPasswordsDoNotMatch;
            }

            // Check if information is correct
            if (UserManager.Instance.AuthenticateUser(this.Page.User.Identity.Name, this.OldPasswordTextbox.Text) == true)
            {
                // Login Information is correct.
                try
                {
                    UserManager.Instance.SetUserPassword(this.SessionManager.UserId, this.NewPasswordTextbox.Text);
                    this.ChangePasswordDiv.Visible = false;
                    this.PasswordChangedDiv.Visible = true;
                    this.SuccessMessage(Resources.Main.PasswordChanged);
                }
                catch
                {
                    this.AddErrorMessage(Resources.Main.PasswordChangeError);
                }
            }
            else
            {
                // Login Information is incorrect.
                this.ErrorLabel.InnerText = Resources.Main.OldPasswordIsIncorrect;
            }
        }

        /// <summary>
        /// Event Handler for when Cancel Button is clicked.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void CancelButton_Clicked(object sender, EventArgs e)
        {
            Response.Redirect(CommonConstants.Urls.Secure.Default);
        }

        #endregion Protected Methods
    }
}
