//-----------------------------------------------------------------------
// <copyright file="Default.aspx.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that represents a Default.</summary>
//-----------------------------------------------------------------------
namespace TimesheetWebApplication.Secure
{
    using System;
    using System.Data;
    using BusinessLogicLayer;
    using BusinessObjects.Collections;
    using BusinessObjects.Filters;
    using TimesheetWebApplication.App_Code;

    /// <summary>
    /// Class that represents Default page.
    /// </summary>
    public partial class Default : SecurePage
    {
        #region Protected Methods

        /// <summary>
        /// Event Handler for on page load.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!this.IsPostBack)
            {
                this.PopulatePage();
            }
        }

        #endregion Protected Methods

        #region Private Methods

        /// <summary>
        /// Populates the page.
        /// </summary>
        private void PopulatePage()
        {
            QueryStringManager manager = new QueryStringManager();

            // My Saved Timesheets
            manager.Clear();
            manager.Add(CommonConstants.QueryStringVariables.TimesheetView, CommonConstants.TimesheetView.MyView.ToString());
            manager.Add(CommonConstants.QueryStringVariables.TimesheetStatusId, Convert.ToInt16(BusinessLogicLayer.Utilities.CommonConstants.TimesheetStatuses.Saved).ToString());
            this.MySavedTimesheets.MoreLinkUrl = QueryStringManager.AddValueToUrl(
                CommonConstants.Urls.Secure.Timesheets,
                CommonConstants.QueryStringVariables.Request,
                manager.Encrypt());
            TimesheetFilter filter = new TimesheetFilter();
            filter.MaxRecords = CommonConstants.Configuration.TimesheetsOverviewRowCount;
            filter.UserId = this.UserId;
            filter.TimesheetStatusId = Convert.ToInt16(BusinessLogicLayer.Utilities.CommonConstants.TimesheetStatuses.Saved);
            TimesheetCollection mySavedTimesheets = TimesheetManager.Instance.GetTimesheets(this.UserId, filter);
            this.MySavedTimesheets.DataSource = mySavedTimesheets;
            this.MySavedTimesheets.DataBind();

            // My submitted
            manager.Clear();
            manager.Add(CommonConstants.QueryStringVariables.TimesheetView, CommonConstants.TimesheetView.MyView.ToString());
            manager.Add(CommonConstants.QueryStringVariables.TimesheetStatusId, Convert.ToInt16(BusinessLogicLayer.Utilities.CommonConstants.TimesheetStatuses.Submitted).ToString());
            this.MySubmittedTimesheets.MoreLinkUrl = QueryStringManager.AddValueToUrl(
                CommonConstants.Urls.Secure.Timesheets,
                CommonConstants.QueryStringVariables.Request,
                manager.Encrypt());
            filter.TimesheetStatusId = Convert.ToInt16(BusinessLogicLayer.Utilities.CommonConstants.TimesheetStatuses.Submitted);
            TimesheetCollection mySubmittedTimesheets = TimesheetManager.Instance.GetTimesheets(this.UserId, filter);
            this.MySubmittedTimesheets.DataSource = mySubmittedTimesheets;
            this.MySubmittedTimesheets.DataBind();

            // My submitted
            manager.Clear();
            manager.Add(CommonConstants.QueryStringVariables.TimesheetView, CommonConstants.TimesheetView.MyView.ToString());
            manager.Add(CommonConstants.QueryStringVariables.TimesheetStatusId, Convert.ToInt16(BusinessLogicLayer.Utilities.CommonConstants.TimesheetStatuses.Declined).ToString());
            this.MyDeclinedTimesheets.MoreLinkUrl = QueryStringManager.AddValueToUrl(
                CommonConstants.Urls.Secure.Timesheets,
                CommonConstants.QueryStringVariables.Request,
                manager.Encrypt());
            filter.TimesheetStatusId = Convert.ToInt16(BusinessLogicLayer.Utilities.CommonConstants.TimesheetStatuses.Declined);
            TimesheetCollection myDeclinedTimesheets = TimesheetManager.Instance.GetTimesheets(this.UserId, filter);
            this.MyDeclinedTimesheets.DataSource = myDeclinedTimesheets;
            this.MyDeclinedTimesheets.DataBind();

            // My approved
            manager.Clear();
            manager.Add(CommonConstants.QueryStringVariables.TimesheetView, CommonConstants.TimesheetView.MyView.ToString());
            manager.Add(CommonConstants.QueryStringVariables.TimesheetStatusId, Convert.ToInt16(BusinessLogicLayer.Utilities.CommonConstants.TimesheetStatuses.Approved).ToString());
            this.MyApprovedTimesheets.MoreLinkUrl = QueryStringManager.AddValueToUrl(
                CommonConstants.Urls.Secure.Timesheets,
                CommonConstants.QueryStringVariables.Request,
                manager.Encrypt());
            filter.TimesheetStatusId = Convert.ToInt16(BusinessLogicLayer.Utilities.CommonConstants.TimesheetStatuses.Approved);
            TimesheetCollection myApprovedTimesheets = TimesheetManager.Instance.GetTimesheets(this.UserId, filter);
            this.MyApprovedTimesheets.DataSource = myApprovedTimesheets;
            this.MyApprovedTimesheets.DataBind();

            if (UserManager.Instance.IsUserApprover(this.UserId))
            {
                // Awaiting Approval
                this.TimesheetsWaitingApproval.Visible = true;
                manager.Clear();
                manager.Add(CommonConstants.QueryStringVariables.TimesheetView, CommonConstants.TimesheetView.Others.ToString());
                manager.Add(CommonConstants.QueryStringVariables.TimesheetStatusId, Convert.ToInt16(BusinessLogicLayer.Utilities.CommonConstants.TimesheetStatuses.Submitted).ToString());
                this.TimesheetsWaitingApproval.MoreLinkUrl = QueryStringManager.AddValueToUrl(
                    CommonConstants.Urls.Secure.Timesheets,
                    CommonConstants.QueryStringVariables.Request,
                    manager.Encrypt());
                filter.UserId = null;
                filter.ApproverUserId = this.UserId;
                filter.TimesheetStatusId = Convert.ToInt16(BusinessLogicLayer.Utilities.CommonConstants.TimesheetStatuses.Submitted);
                TimesheetCollection awaitingApprovelTimesheets = TimesheetManager.Instance.GetTimesheets(this.UserId, filter);
                this.TimesheetsWaitingApproval.DataSource = awaitingApprovelTimesheets;
                this.TimesheetsWaitingApproval.DataBind();
            }
            else
            {
                this.TimesheetsWaitingApproval.Visible = false;
            }
        }

        #endregion Private Methods
    }
}
