//-----------------------------------------------------------------------
// <copyright file="Timesheets.aspx.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds page that shows timesheets.</summary>
//-----------------------------------------------------------------------
namespace TimesheetWebApplication.Secure
{
    using System;
    using System.Data;
    using System.Web.UI.WebControls;
    using BusinessLogicLayer;
    using BusinessObjects.Collections;
    using TimesheetWebApplication.App_Code;

    /// <summary>
    /// Class tha represents Timesheets page.
    /// </summary>
    public partial class Timesheets : SecurePage
    {
        #region Protected Methods

        /// <summary>
        /// Event Handler for on page load.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!this.IsPostBack)
            {
                this.HandleQueryString();
                this.PopulatePage();
            }
        }

        /// <summary>
        /// Event Handler for on SearchButton click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void SearchButton_Clicked(object sender, EventArgs e)
        {
            this.SessionManager.TimesheetsFilter.EndDateTime = this.TimesheetFilterWebUserControl.EndDate;
            this.SessionManager.TimesheetsFilter.StartDateTime = this.TimesheetFilterWebUserControl.StartDate;
            this.SessionManager.TimesheetsFilter.TimesheetStatusId = this.TimesheetFilterWebUserControl.TimesheetStatusId;
            this.SessionManager.TimesheetsFilter.UserId = this.TimesheetFilterWebUserControl.UserId;
            this.PopulateTimesheetsTabPanel(1);
        }

        /// <summary>
        /// Event Handler for on SearchClearButton click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void SearchClearButton_Clicked(object sender, EventArgs e)
        {
            this.SessionManager.ClearTimesheetsFilter();
            this.TimesheetFilterWebUserControl.SetData(this.SessionManager.TimesheetsFilter);
            this.PopulateTimesheetsTabPanel(1);
        }

        /// <summary>
        /// Event Handler for when Timesheets PageChanged.
        /// </summary>
        /// <param name="pageNumber">The new page number.</param>
        protected void Timesheets_PageChanged(int pageNumber)
        {
            this.PopulateTimesheetsTabPanel(pageNumber);
        }

        /// <summary>
        /// Event Handler for on MySearchButton click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void MySearchButton_Clicked(object sender, EventArgs e)
        {
            this.SessionManager.MyTimesheetsFilter.EndDateTime = this.MyTimesheetFilterWebUserControl.EndDate;
            this.SessionManager.MyTimesheetsFilter.StartDateTime = this.MyTimesheetFilterWebUserControl.StartDate;
            this.SessionManager.MyTimesheetsFilter.TimesheetStatusId = this.MyTimesheetFilterWebUserControl.TimesheetStatusId;
            this.PopulateMyTimesheetsTabPanel(1);
        }

        /// <summary>
        /// Event Handler for on MySearchClearButton click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void MySearchClearButton_Clicked(object sender, EventArgs e)
        {
            this.SessionManager.ClearMyTimesheetsFilter();
            this.MyTimesheetFilterWebUserControl.SetData(this.SessionManager.MyTimesheetsFilter);
            this.PopulateMyTimesheetsTabPanel(1);
        }

        /// <summary>
        /// Event Handler for when MyTimesheets PageChanged.
        /// </summary>
        /// <param name="pageNumber">The new page number.</param>
        protected void MyTimesheets_PageChanged(int pageNumber)
        {
            this.PopulateMyTimesheetsTabPanel(pageNumber);
        }

        /// <summary>
        /// Event Handler for on DeleteMyTimesheet click.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void DeleteMyTimesheet_Clicked(object sender, EventArgs e)
        {
            long id = Convert.ToInt64((sender as LinkButton).CommandArgument);
            BusinessLogicLayer.TimesheetManager.Instance.DeleteAllTimesheet(id);
            this.PopulateMyTimesheetsTabPanel(this.MyTimesheetsPager.CurrentPageNumber);
        }

        #endregion Protected Methods

        #region Private Methods

        /// <summary>
        /// Handles the questring, assuming there is one.
        /// </summary>
        private void HandleQueryString()
        {
            if (this.QueryStringManager.HasRequest)
            {
                QueryStringManager decrypted = new QueryStringManager(this.QueryStringManager.Request);
                if (decrypted.HasTimesheetView)
                {
                    if (decrypted.HasTimesheetStatusId)
                    {
                        switch (decrypted.TimesheetView)
                        {
                            case CommonConstants.TimesheetView.MyView:
                                this.TimesheetsTabContainer.TabIndex = 0;
                                this.SessionManager.MyTimesheetsFilter.TimesheetStatusId = decrypted.TimesheetStatusId;
                                break;

                            case CommonConstants.TimesheetView.Others:
                                this.TimesheetsTabContainer.TabIndex = 1;
                                this.SessionManager.TimesheetsFilter.TimesheetStatusId = decrypted.TimesheetStatusId;
                                break;
                        }
                    }
                }
            }
        }

        /// <summary>
        /// Populates the page.
        /// </summary>
        private void PopulatePage()
        {
            if (!BusinessLogicLayer.UserManager.Instance.IsUserApprover(this.UserId)
                    && !this.IsUserAdministrator
                    && !this.IsUserManager)
            {
                // User is not an approver therefore hide the panel that would show other uses's timesheets.
                this.TimesheetsTabPanel.Visible = false;
                this.TimesheetsTabPanel.HeaderText = string.Empty;
                this.TimesheetsTabContainer.TabIndex = 0;
            }
            else
            {
                // User is an approver, admin or manager therefore populate the timesheets tab
                this.TimesheetsPager.MaxButtons = CommonConstants.Configuration.MaxPagingButtons;
                this.PopulateTimesheetsTabPanel(1);
            }

            this.MyTimesheetsPager.MaxButtons = CommonConstants.Configuration.MaxPagingButtons;
            this.PopulateMyTimesheetsTabPanel(1);
        }

        /// <summary>
        /// Populates the Timesheets Tab Panel.
        /// </summary>
        /// <param name="pageNumber">The page number to show.</param>
        private void PopulateTimesheetsTabPanel(int pageNumber)
        {
            this.TimesheetFilterWebUserControl.SetData(this.SessionManager.TimesheetsFilter);
            DataTable result = this.CreateTimesheetsDataTable(pageNumber);
            if (result.Rows.Count == 0)
            {
                this.TimesheetsRepeater.Visible = false;
                this.TimesheetsBlankDiv.Visible = true;
            }
            else
            {
                this.TimesheetsRepeater.Visible = true;
                this.TimesheetsBlankDiv.Visible = false;
                this.TimesheetsRepeater.DataSource = result;
                this.TimesheetsRepeater.DataBind();
            }
        }

        /// <summary>
        /// Creates a datatable for the timesheets repeater.
        /// </summary>
        /// <param name="pageNumber">The page number to display.</param>
        /// <returns>Table with timesheets.</returns>
        private DataTable CreateTimesheetsDataTable(int pageNumber)
        {
            DataTable result = new DataTable();
            result.Columns.Add("Employee Id", typeof(string));
            result.Columns.Add("Name", typeof(string));
            result.Columns.Add("Week End", typeof(string));
            result.Columns.Add("Status", typeof(string));
            result.Columns.Add("Status Changer", typeof(string));
            result.Columns.Add("Status Changed Date", typeof(string));
            result.Columns.Add("URL", typeof(string));

            TimesheetCollection timesheets = TimesheetManager.Instance.GetTimesheets(this.SessionManager.UserId, this.SessionManager.TimesheetsFilter);
            if (timesheets.Count > 0)
            {
                this.TimesheetsPager.TotalPages = timesheets.GetTotalPages(CommonConstants.Configuration.PageSize);
                TimesheetCollection pageCollection = timesheets.GetPage(CommonConstants.Configuration.PageSize, pageNumber);
                while (pageCollection.Count == 0)
                {
                    pageCollection = timesheets.GetPage(CommonConstants.Configuration.PageSize, pageNumber--);
                    this.TimesheetsPager.CurrentPageNumber = pageNumber;
                }

                foreach (BusinessObjects.Timesheet timesheet in timesheets)
                {
                    DataRow row = result.NewRow();
                    BusinessObjects.User user = UserManager.Instance.GetUser(timesheet.UserId);
                    row["Employee Id"] = user.EmployeeId;
                    row["Name"] = user.FullName;
                    row["Week End"] = timesheet.WeekEndDate.ToString(CommonConstants.Configuration.DateFormat);
                    row["Status"] = TimesheetStatusManager.Instance.GetTimesheetStatus(timesheet.TimesheetStatusId).Name;
                    row["Status Changer"] = UserManager.Instance.GetUser(timesheet.StatusChangerUserId).FullName;
                    row["Status Changed Date"] = timesheet.StatusChangeDateTime.ToString(CommonConstants.Configuration.DateTimeFormat);

                    // Encrypt querystring
                    QueryStringManager manager = new QueryStringManager();
                    manager.Add(CommonConstants.QueryStringVariables.TimesheetId, timesheet.TimesheetId.ToString());
                    row["URL"] = ResolveUrl(QueryStringManager.AddValueToUrl(
                        CommonConstants.Urls.Secure.Timesheet,
                        CommonConstants.QueryStringVariables.Request,
                        manager.Encrypt()));

                    result.Rows.Add(row);
                }
            }
            
            return result;
        }

        /// <summary>
        /// Populates the My Timesheets Tab Panel.
        /// </summary>
        /// <param name="pageNumber">The page number to show.</param>
        private void PopulateMyTimesheetsTabPanel(int pageNumber)
        {
            this.MyTimesheetFilterWebUserControl.SetData(this.SessionManager.MyTimesheetsFilter);
            DataTable result = this.CreateMyTimesheetsDataTable(pageNumber);
            if (result.Rows.Count == 0)
            {
                this.MyTimesheetsRepeater.Visible = false;
                this.MyTimesheetsBlankDiv.Visible = true;
            }
            else
            {
                this.MyTimesheetsRepeater.Visible = true;
                this.MyTimesheetsBlankDiv.Visible = false;
                this.MyTimesheetsRepeater.DataSource = result;
                this.MyTimesheetsRepeater.DataBind();
            }
        }

        /// <summary>
        /// Creates a datatable for the timesheets repeater.
        /// </summary>
        /// <param name="pageNumber">The page number to display.</param>
        /// <returns>The data table conating the result.</returns>
        private DataTable CreateMyTimesheetsDataTable(int pageNumber)
        {
            DataTable result = new DataTable();
            result.Columns.Add("TimesheetId", typeof(long));
            result.Columns.Add("Week End", typeof(string));
            result.Columns.Add("Status", typeof(string));
            result.Columns.Add("Status Changer", typeof(string));
            result.Columns.Add("Status Changed Date", typeof(string));
            result.Columns.Add("CanDelete", typeof(bool));
            result.Columns.Add("URL", typeof(string));

            TimesheetCollection timesheets = TimesheetManager.Instance.GetTimesheets(this.SessionManager.UserId, this.SessionManager.MyTimesheetsFilter);
            if (timesheets.Count > 0)
            {
                this.MyTimesheetsPager.TotalPages = timesheets.GetTotalPages(CommonConstants.Configuration.PageSize);
                TimesheetCollection pageCollection = timesheets.GetPage(CommonConstants.Configuration.PageSize, pageNumber);
                while (pageCollection.Count == 0)
                {
                    pageCollection = timesheets.GetPage(CommonConstants.Configuration.PageSize, pageNumber--);
                    this.MyTimesheetsPager.CurrentPageNumber = pageNumber;
                }

                foreach (BusinessObjects.Timesheet timesheet in pageCollection)
                {
                    DataRow row = result.NewRow();
                    row["TimesheetId"] = timesheet.TimesheetId;
                    row["Week End"] = timesheet.WeekEndDate.ToString(CommonConstants.Configuration.DateFormat);
                    row["Status"] = TimesheetStatusManager.Instance.GetTimesheetStatus(timesheet.TimesheetStatusId).Name;
                    row["Status Changer"] = UserManager.Instance.GetUser(timesheet.StatusChangerUserId).FullName;
                    row["Status Changed Date"] = timesheet.StatusChangeDateTime.ToString(CommonConstants.Configuration.DateTimeFormat);
                    row["CanDelete"] = TimesheetManager.Instance.CanOwnerDeleteTimesheet(timesheet.TimesheetId);

                    // Encrypt querystring
                    QueryStringManager manager = new QueryStringManager();
                    manager.Add(CommonConstants.QueryStringVariables.TimesheetId, timesheet.TimesheetId.ToString());
                    row["URL"] = ResolveUrl(QueryStringManager.AddValueToUrl(
                        CommonConstants.Urls.Secure.Timesheet,
                        CommonConstants.QueryStringVariables.Request,
                        manager.Encrypt()));

                    result.Rows.Add(row);
                }
            }

            return result;
        }

        #endregion Private Methods
    }
}
