//-----------------------------------------------------------------------
// <copyright file="JobCodeFilter.ascx.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that represents a JobCodeFilter control.</summary>
//-----------------------------------------------------------------------
namespace TimesheetWebApplication.WebUserControls
{
    using System;
    using System.Web.UI.WebControls;
    using BusinessLogicLayer;
    using BusinessObjects;
    using BusinessObjects.Collections;
    using BusinessObjects.Filters;
    using TimesheetWebApplication.App_Code;

    /// <summary>
    /// Class that represents the JobCodeFilter
    /// </summary>
    public partial class JobCodeFilter : BaseUserControl
    {
        #region Public Properties

        /// <summary>Gets or sets controls style.</summary>
        public string CssClass
        {
            get { return this.FilterDiv.Attributes["class"]; }
            set { this.FilterDiv.Attributes["class"] = value; }
        }

        /// <summary>
        /// Gets or sets the selected Organisation from the filter.
        /// </summary>
        public int? OrganisationId
        {
            get
            {
                User user = UserManager.Instance.GetUser((this.Page as SecurePage).UserId);
                if (user.OrganisationId.HasValue)
                {
                    return user.OrganisationId.Value;
                }

                if (this.OrganisationList.SelectedIndex <= 0)
                {
                    return null;
                }

                return Convert.ToInt32(this.OrganisationList.SelectedValue);
            }

            set
            {
                if (value.HasValue)
                {
                    try
                    {
                        this.OrganisationList.SelectedValue = value.Value.ToString();
                    }
                    catch
                    {
                    }
                }
                else
                {
                    this.OrganisationList.SelectedIndex = -1;
                }
            }
        }

        /// <summary>Gets or sets the validation group.</summary>
        public string ValidationGroup
        {
            get
            {
                return this.OrganisationRequiredFieldValidator.ValidationGroup;
            }

            set
            {
                this.OrganisationRequiredFieldValidator.ValidationGroup = value;
            }
        }

        #endregion Public Properties

        #region Protected Methods

        /// <summary>
        /// Event Handler for on OnInit.
        /// </summary>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected override void OnInit(EventArgs e)
        {
            base.OnInit(e);

            if (!this.IsPostBack)
            {
                this.PopulateControl();
            }
        }

        /// <summary>
        /// Event Handler for on page load.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void Page_Load(object sender, EventArgs e)
        {
        }

        #endregion Protected Methods

        #region Private Methods

        /// <summary>
        /// Populates the control.
        /// </summary>
        private void PopulateControl()
        {
            /*User user = UserManager.Instance.GetUser((this.Page as SecurePage).UserId);
            if (user.OrganisationId.HasValue)
            {
                this.OrganisationDiv.Visible = false;
            }
            else
            {
                this.PopulateOrganisationList();
            }*/

            SecurePage securePage = this.Page as SecurePage;
            if (securePage.IsUserAdministrator)
            {
                this.OrganisationDiv.Visible = true;
                this.PopulateOrganisationList();
            }
            else
            {
                if (!securePage.IsUserInOrganisation)
                {
                    this.OrganisationDiv.Visible = true;
                    this.PopulateOrganisationList();
                }
                else
                {
                    // Don't show org
                    this.OrganisationDiv.Visible = false;
                }
            }
        }

        /// <summary>
        /// Populates the Organisation List.
        /// </summary>
        private void PopulateOrganisationList()
        {
            OrganisationCollection orgs = OrganisationManager.Instance.GetOrganisations(null);
            this.OrganisationList.Items.Clear();
            this.OrganisationList.Items.Add(BasePage.NullItem);
            foreach (Organisation org in orgs)
            {
                this.OrganisationList.Items.Add(new ListItem(org.Name, org.OrganisationId.ToString()));
            }
        }

        #endregion Private Methods
    }
}