//-----------------------------------------------------------------------
// <copyright file="TimesheetsOverview.ascx.cs" company="Yasar Bhatti">Copyright(c) Yasar Bhatti. All rights reserved.</copyright>
// <author>Yasar Bhatti</author>
// <summary>Holds class that represents a TimesheetsOverview control.</summary>
//-----------------------------------------------------------------------
namespace TimesheetWebApplication.WebUserControls
{
    using System;
    using System.Data;
    using System.Web.UI.WebControls;
    using BusinessLogicLayer;
    using BusinessObjects;
    using BusinessObjects.Collections;
    using TimesheetWebApplication.App_Code;

    /// <summary>
    /// Class that represents TimesheetsOverview control.
    /// </summary>
    public partial class TimesheetsOverview : BaseUserControl
    {
        #region Private Properties

        /// <summary>Holds the timesheets.</summary>
        private TimesheetCollection timesheets;

        /// <summary>Holds whether or not to show the username column.</summary>
        private bool showUserNameColumn = false;

        /// <summary>Holds the header text.</summary>
        private string headerText;

        /// <summary>Holds the description text.</summary>
        private string descriptionText;

        #endregion Preivate Properties

        #region Public Properties

        /// <summary>Gets or sets controls style.</summary>
        public string CssClass
        {
            get { return this.TimesheetsDiv.Attributes["class"]; }
            set { this.TimesheetsDiv.Attributes["class"] = value; }
        }

        /// <summary>Gets or sets the header.</summary>
        public string HeaderText
        {
            get { return this.headerText; }
            set { this.headerText = value; }
        }

        /// <summary>Gets or sets the more link url.</summary>
        public string MoreLinkUrl
        {
            get { return this.HeaderHyperLink.NavigateUrl; }
            set { this.HeaderHyperLink.NavigateUrl = value; }
        }

        /// <summary>Gets or sets the Description.</summary>
        public string DescriptionText
        {
            get { return this.descriptionText; }
            set { this.descriptionText = value; }
        }

        /// <summary>
        /// Gets or sets the DataSource of the control.
        /// </summary>
        public TimesheetCollection DataSource
        {
            get { return this.timesheets; }
            set { this.timesheets = value; }
        }

        /// <summary>
        /// Gets or sets a value indicating whether or not to show the Username.
        /// </summary>
        public bool ShowUserNameColumn
        {
            get { return this.showUserNameColumn; }
            set { this.showUserNameColumn = value; }
        }

        #endregion Public Properties

        #region Public Methods

        /// <summary>
        /// Binds the data from the datasource to this control.
        /// </summary>
        public override void DataBind()
        {
            this.TimesheetsRepeater.DataSource = this.CreateDataTable();
            this.TimesheetsRepeater.DataBind();
        }

        #endregion Public Methods

        #region Protected Methods

        /// <summary>
        /// Event Handler for on page load.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void Page_Load(object sender, EventArgs e)
        {
        }

        #endregion Protected Methods 

        #region Private Methods

        /// <summary>
        /// Creates a datatable from the timesheet collection 
        /// </summary>
        /// <returns>DataTable from the timesheets.</returns>
        private DataTable CreateDataTable()
        {
            DataTable result = new DataTable();
            result.Columns.Add("Username", typeof(string));
            result.Columns.Add("TimesheetId", typeof(long));
            result.Columns.Add("Week End", typeof(string));
            result.Columns.Add("Last Changed", typeof(string));
            result.Columns.Add("URL", typeof(string));

            if (this.timesheets.Count > 0)
            {
                this.TimesheetsBlankDiv.Visible = false;
                this.TimesheetsRepeater.Visible = true;

                foreach (BusinessObjects.Timesheet timesheet in this.timesheets)
                {
                    DataRow row = result.NewRow();
                    row["Username"] = UserManager.Instance.GetUser(timesheet.UserId).FullName;
                    row["TimesheetId"] = timesheet.TimesheetId;
                    row["Week End"] = timesheet.WeekEndDate.ToString(CommonConstants.Configuration.DateFormat);
                    row["Last Changed"] = timesheet.StatusChangeDateTime.ToString(CommonConstants.Configuration.DateTimeFormat);

                    // Encrypt querystring
                    QueryStringManager manager = new QueryStringManager();
                    manager.Add(CommonConstants.QueryStringVariables.TimesheetId, timesheet.TimesheetId.ToString());
                    row["URL"] = ResolveUrl(QueryStringManager.AddValueToUrl(
                        CommonConstants.Urls.Secure.Timesheet,
                        CommonConstants.QueryStringVariables.Request,
                        manager.Encrypt()));

                    result.Rows.Add(row);
                }
            }
            else
            {
                this.TimesheetsBlankDiv.Visible = true;
                this.TimesheetsRepeater.Visible = false;
            }

            return result;
        }

        #endregion Private Methods
    }
}